@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 5302 2012-10-22 05:30:57Z fishbone $
+ * @version    SVN: $Id: scriptLibInfo.php 5358 2012-11-01 12:50:02Z fishbone $
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
@@ -57,6 +57,7 @@ class ScriptLibInfo
 	const LIB_JQUERY_IFRAME			= 'jquery.iframe';
 	const LIB_JQUERY_RATY			= 'jquery.raty';
 	const LIB_JQUERY_MOUSEWHEEL		= 'jquery.mousewheel';
+	const LIB_JQUERY_CLOUDCAROUSEL	= 'jquery.cloudcarousel';
 //	const LIB_JQUERY_JQEASYPANEL	= 'jquery.jqeasypanel';
 	
 	// jQueryプラグインバージョン
@@ -70,6 +71,7 @@ class ScriptLibInfo
 	const JQUERY_IFRAME_VER			= '1.5.0';
 	const JQUERY_RATY_VER			= '1.4.3';
 	const JQUERY_MOUSEWHEEL_VER		= '3.0.6';
+	const JQUERY_CLOUDCAROUSEL_VER	= '1.0.5';
 //	const JQUERY_JQEASYPANEL_VER	= '1.0';
 	
 	// ライブラリディレクトリ
@@ -131,6 +133,7 @@ class ScriptLibInfo
 	const JQUERY_IFRAME_FILENAME		= 'jquery/jquery.iframe-auto-height.plugin.1.7.1.min.js';
 	const JQUERY_RATY_FILENAME			= 'jquery/raty/jquery.raty.js';
 	const JQUERY_MOUSEWHEEL_FILENAME	= 'jquery/jquery.mousewheel.js';
+	const JQUERY_CLOUDCAROUSEL_FILENAME	= 'jquery/cloud-carousel.1.0.5.min.js';
 //	const JQUERY_JQEASYPANEL_FILENAME	= 'jquery/jquery.jqEasyPanel.js';
 //	const JQUERY_JQEASYPANEL_CSS		= 'jquery/jqeasypanel.css';
 	
@@ -146,6 +149,7 @@ class ScriptLibInfo
 	const JQUERY_IFRAME_URL				= 'https://github.com/house9/jquery-iframe-auto-height';
 	const JQUERY_RATY_URL				= 'http://www.wbotelhos.com/raty/';
 	const JQUERY_MOUSEWHEEL_URL			= 'https://github.com/brandonaaron/jquery-mousewheel';
+	const JQUERY_CLOUDCAROUSEL_URL		= 'http://www.professorcloud.com/mainsite/carousel.htm';
 //	const JQUERY_JQEASYPANEL_URL		= 'http://www.jqeasy.com/';
 	
 	// ディレクトリ名
@@ -304,7 +308,10 @@ class ScriptLibInfo
 																'version'	=>	self::JQUERY_RATY_VER),
 					self::LIB_JQUERY_MOUSEWHEEL		=>	array(	'script'	=> array(self::JQUERY_MOUSEWHEEL_FILENAME),		// jquery.mousewheel用のファイル
 																'url'		=>	self::JQUERY_MOUSEWHEEL_URL,
-																'version'	=>	self::JQUERY_MOUSEWHEEL_VER)
+																'version'	=>	self::JQUERY_MOUSEWHEEL_VER),
+					self::LIB_JQUERY_CLOUDCAROUSEL	=>	array(	'script'	=> array(self::JQUERY_CLOUDCAROUSEL_FILENAME),		// jquery.cloudcarousel用のファイル
+																'url'		=>	self::JQUERY_CLOUDCAROUSEL_URL,
+																'version'	=>	self::JQUERY_CLOUDCAROUSEL_VER)
 /*					self::LIB_JQUERY_JQEASYPANEL	=>	array(	'script' 	=> array(self::JQUERY_JQEASYPANEL_FILENAME),	// jquery.jqEasyPanel用のファイル
 																'css'		=>	array(self::JQUERY_JQEASYPANEL_CSS),
 																'url'		=>	self::JQUERY_JQEASYPANEL_URL,
