@@ -11,9 +11,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseAdminWidgetContainer.php 4240 2011-08-08 05:25:19Z fishbone $
+ * @version    SVN: $Id: baseAdminWidgetContainer.php 4963 2012-06-13 12:19:09Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -67,12 +67,20 @@ class BaseAdminWidgetContainer extends BaseWidgetContainer
 			$helpKeys = array();
 			if (method_exists($this, '_setHelp')){
 				$helpId = $this->_setHelp($request, $param);
-				$helpKeys = $this->gInstance->getHelpManager()->loadHelp($this->gEnv->getCurrentWidgetId(), $helpId, $this);
+				$helpKeys = $this->gInstance->getHelpManager()->loadHelp($this->gEnv->getCurrentWidgetId(), false/*新規モード*/, $helpId, $this);
 			}
-			
+
 			// ヘルプIDが設定されていない場合は共通ファイルを読み込む
-			if (empty($helpKeys)) $helpKeys = $this->gInstance->getHelpManager()->loadHelp($this->gEnv->getCurrentWidgetId());
-				
+			if (empty($helpKeys)){
+				// 代替ウィジェットが設定されている場合は代替ウィジェットのヘルプを読み込む
+				if (!empty($this->_defaultWidgetId)) $helpKeys = $this->gInstance->getHelpManager()->loadHelp($this->_defaultWidgetId);
+
+				// カレントウィジェットのヘルプを読み込む
+				$isAdd = false;		// 追加モード
+				if (!empty($this->_defaultWidgetId)) $isAdd = true;		// 追加モード
+				$helpKeys = $this->gInstance->getHelpManager()->loadHelp($this->gEnv->getCurrentWidgetId(), $isAdd);
+			}
+
 			// テンプレート上のヘルプタグを変換
 			for ($i = 0; $i < count($helpKeys); $i++){
 				$key = $helpKeys[$i];
