@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 5137 2012-08-24 00:51:50Z fishbone $
+ * @version    SVN: $Id: baseFrameContainer.php 5405 2012-11-23 10:32:12Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -758,6 +758,10 @@ class BaseFrameContainer extends Core
 				// URLの引数として、ページIDとページサブIDが指定されてくる
 				if ($pageId == $this->gEnv->getDefaultPageId()){		// 通常サイトのとき
 					$curTemplate = $this->gSystem->defaultTemplateId();
+
+					// URLの引数でテンプレートIDが指定されている場合は設定
+					$templateId = $request->trimValueOf(M3_REQUEST_PARAM_TEMPLATE_ID);		// テンプレートIDを取得
+					if (!empty($templateId)) $curTemplate = $templateId;
 				} else if ($pageId == $this->gEnv->getDefaultMobilePageId()){		// 携帯サイトのとき
 					$curTemplate = $this->gSystem->defaultMobileTemplateId();		// 携帯用デフォルトテンプレート
 				} else if ($pageId == $this->gEnv->getDefaultSmartphonePageId()){		// スマートフォン用サイトのとき
