@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseDb.php 4263 2011-08-29 03:39:15Z fishbone $
+ * @version    SVN: $Id: baseDb.php 5447 2012-12-09 01:33:40Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -973,7 +973,8 @@ class BaseDb extends Core
 	function _preConvSql($src)
 	{
 		// 「--」以降のSQLをPostgreSQL9.0用のSQLとする
-		$str = '/^(.+?;) *-- *(.+?;)(.*?)$/m';
+		//$str = '/^(.+?;) *-- *(.+?;)(.*?)$/m';
+		$str = '/^(.+?;) *-- *(.+?;) *--(.*?)$/m';
         $dest = preg_replace_callback($str, array($this, '_pre_conv_sql_callback'), $src);
 		return $dest;
 	}
