@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: JRender.php 4902 2012-05-03 12:18:19Z fishbone $
+ * @version    SVN: $Id: JRender.php 5336 2012-10-27 09:34:40Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($this->gEnv->getJoomlaRootPath() . '/JParameter.php');
@@ -243,7 +243,8 @@ $this->item->title = '****';*/
 			if ($templateVer == 2){// Joomla!v2.5テンプレート
 				require_once($gEnvManager->getJoomlaRootPath() . '/class/moduleHelper.php');
 			}
-			require_once($helper);		// デフォルトの出力方法
+			//require_once($helper);		// デフォルトの出力方法
+			require($helper);		// デフォルトの出力方法
 			require($menuPath);		// 毎回実行する
 			$contents = ob_get_contents();
 			ob_clean();
