@@ -10,13 +10,13 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installCopyfileWidgetContainer.php 2836 2010-02-05 06:50:09Z fishbone $
+ * @version    SVN: $Id: _installCopyfileWidgetContainer.php 3795 2010-11-09 07:12:37Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/_installBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() . '/_installDb.php');
 
-class _installCopyfileWidgetContainer extends BaseWidgetContainer
+class _installCopyfileWidgetContainer extends _installBaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
 	private $templateIdArray = array();			// コピーしたテンプレートID
@@ -81,13 +81,13 @@ class _installCopyfileWidgetContainer extends BaseWidgetContainer
 			if ($ret){
 				// ディレクトリの存在チェック
 				if ($isResourceDir){
-					if (!is_dir($rootDir . '/' . M3_DIR_NAME_RESOURCE)) $this->setMsg(self::MSG_APP_ERR, "リソースディレクトリが見つかりません");
+					if (!is_dir($rootDir . '/' . M3_DIR_NAME_RESOURCE)) $this->setMsg(self::MSG_APP_ERR, $this->_('Resource directory not found.'));		// リソースディレクトリが見つかりません
 				}
 				if ($isTemplate){
-					if (!is_dir($rootDir . '/' . M3_DIR_NAME_TEMPLATES)) $this->setMsg(self::MSG_APP_ERR, "テンプレートディレクトリが見つかりません");
+					if (!is_dir($rootDir . '/' . M3_DIR_NAME_TEMPLATES)) $this->setMsg(self::MSG_APP_ERR, $this->_('Template directory not found.'));// テンプレートディレクトリが見つかりません
 				}
 				if ($isWidget){
-					if (!is_dir($rootDir . '/' . M3_DIR_NAME_WIDGETS)) $this->setMsg(self::MSG_APP_ERR, "ウィジェットディレクトリが見つかりません");
+					if (!is_dir($rootDir . '/' . M3_DIR_NAME_WIDGETS)) $this->setMsg(self::MSG_APP_ERR, $this->_('Widget directory not found.'));		// ウィジェットディレクトリが見つかりません
 				}
 			}
 			
@@ -113,7 +113,9 @@ class _installCopyfileWidgetContainer extends BaseWidgetContainer
 						rmDirectory($tmpResourceDir);
 						
 						// 運用ログを残す
-						$this->gOpeLog->writeInfo(__METHOD__, '旧システムのリソースディレクトリをコピーしました。ディレクトリ: ' . $oldResourceDir, 1000);
+						//$this->gOpeLog->writeInfo(__METHOD__, '旧システムのリソースディレクトリをコピーしました。ディレクトリ: ' . $oldResourceDir, 1000);
+						$msg = $this->_('Resource directory in old system copied. Directory: %s');		// 旧システムのリソースディレクトリをコピーしました。ディレクトリ: %s
+						$this->gOpeLog->writeInfo(__METHOD__, sprintf($msg, $oldResourceDir), 1000);
 					} else {
 						// 退避ディレクトリを戻す
 						mvDirectory($tmpResourceDir, $resourceDir);
@@ -136,7 +138,9 @@ class _installCopyfileWidgetContainer extends BaseWidgetContainer
 					// テンプレートを取り込んだときはメッセージを残す
 					if (count($this->templateIdArray) > 0){
 						// 運用ログを残す
-						$this->gOpeLog->writeInfo(__METHOD__, '旧システムのテンプレートをコピーしました。テンプレート: ' . implode($this->templateIdArray, ','), 1000);
+						//$this->gOpeLog->writeInfo(__METHOD__, '旧システムのテンプレートをコピーしました。テンプレート: ' . implode($this->templateIdArray, ','), 1000);
+						$msg = $this->_('Template in old system copied. Template: %s');		// 旧システムのテンプレートをコピーしました。テンプレート: %s
+						$this->gOpeLog->writeInfo(__METHOD__, sprintf($msg, implode($this->templateIdArray, ',')), 1000);
 					}
 				}
 				// ウィジェットディレクトリのコピー
@@ -154,13 +158,15 @@ class _installCopyfileWidgetContainer extends BaseWidgetContainer
 					// ウィジェットを取り込んだときはメッセージを残す
 					if (count($this->widgetIdArray) > 0){
 						// 運用ログを残す
-						$this->gOpeLog->writeInfo(__METHOD__, '旧システムのウィジェットをコピーしました。ウィジェット: ' . implode($this->widgetIdArray, ','), 1000);
+						//$this->gOpeLog->writeInfo(__METHOD__, '旧システムのウィジェットをコピーしました。ウィジェット: %s' . implode($this->widgetIdArray, ','), 1000);
+						$msg = $this->_('Widget in old system copied. Widget: %s');		// 旧システムのウィジェットをコピーしました。ウィジェット: %s
+						$this->gOpeLog->writeInfo(__METHOD__, sprintf($msg, implode($this->widgetIdArray, ',')), 1000);
 					}
 				}
 				if ($isCompleted){
-					$this->setMsg(self::MSG_GUIDANCE, 'ファイルをコピーしました');
+					$this->setMsg(self::MSG_GUIDANCE, $this->_('Files copied.'));		// ファイルをコピーしました
 				} else {
-					$this->setMsg(self::MSG_APP_ERR, "ファイルコピーに失敗しました");
+					$this->setMsg(self::MSG_APP_ERR, $this->_('Failed in copying files.'));		// ファイルコピーに失敗しました
 				}
 			}
 		} else if ($act == 'checkdir'){		// 旧システムのルートディレクトリの位置をチェック
@@ -169,9 +175,9 @@ class _installCopyfileWidgetContainer extends BaseWidgetContainer
 			
 			// エラーなしの場合は正常メッセージを表示
 			if ($this->getMsgCount() == 0){// 入力チェックOKの場合
-				$msg = '<b><font color="green">ディレクトリチェック</font></b>';
+				$msg = '<b><font color="green">' . $this->_('Check directory') . '</font></b>';		// ディレクトリチェック
 				$msg .= ' => ';
-				$msg .= '<b><font color="green">正常</font></b>';
+				$msg .= '<b><font color="green">' . $this->_('Existing') . '</font></b>';			// 正常
 				$this->tmpl->addVar("_widget", "check_msg", $msg);
 			}
 		} else {
@@ -185,8 +191,8 @@ class _installCopyfileWidgetContainer extends BaseWidgetContainer
 		
 		// 画面のヘッダ、タイトルを設定
 		if ($dbStatus == 'update'){
-			$this->tmpl->addVar("_widget", "title", 'ＤＢバージョンアップ完了');
-			$this->tmpl->addVar("install_msg", "message", 'ＤＢバージョンアップが完了しました');
+			$this->tmpl->addVar("_widget", "title", $this->_('Database Updated'));		// ＤＢバージョンアップ完了
+			$this->tmpl->addVar("install_msg", "message", $this->_('Updating database completed.'));			// ＤＢバージョンアップが完了しました
 		}
 		$this->tmpl->addVar("_widget", "db_status", $dbStatus);
 		$this->tmpl->addVar("_widget", "root_dir", $rootDir);
@@ -199,6 +205,20 @@ class _installCopyfileWidgetContainer extends BaseWidgetContainer
 		$checked = '';
 		if ($isWidget) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "is_widget_checked", $checked);
+		
+		// テキストをローカライズ
+		$localeText = array();
+		$localeText['msg_copy_files'] = $this->_('Copy files?');// ファイルをコピーしますか?
+		$localeText['msg_copy_from_old_system'] = $this->_('If you copy files form old system to this system, use this operation field below.<br />If you don\'t, go next.');	// 旧システムのファイルをこのシステムへコピーする場合は以下の処理を実行してください<br />何も行わない場合は「次へ」進みます。
+		$localeText['label_copy_from_old_system'] = $this->_('Copy files in old system');		// 旧システムからファイルをコピー
+		$localeText['label_old_system_dir'] = $this->_('Old System Directory');// 旧システムルートディレクトリ
+		$localeText['label_check_dir'] = $this->_('Check directory');// ディレクトリチェック
+		$localeText['label_target_copy'] = $this->_('Copy Target');// コピー対象
+		$localeText['label_replace_resource'] = $this->_('Replace resource directory');// リソースディレクトリ(/resource) 置き換え
+		$localeText['label_copy_template'] = $this->_('Copy template (difference only)');// テンプレート 差分のみ取得
+		$localeText['label_copy_widget'] = $this->_('Copy widget (difference only)');// ウィジェット 差分のみ取得
+		$localeText['label_copy_files'] = $this->_('Copy files');// ファイルをコピー
+		$this->setLocaleText($localeText);
 	}
 	/**
 	 * ディレクトリの入力チェック
@@ -209,12 +229,12 @@ class _installCopyfileWidgetContainer extends BaseWidgetContainer
 	function checkDir($dir)
 	{
 		if (empty($dir)){
-			$this->setMsg(self::MSG_APP_ERR, "旧システムのルートディレクトリが設定されていません");
+			$this->setMsg(self::MSG_APP_ERR, $this->_('The root directory in old system not selected.'));	// 旧システムのルートディレクトリが設定されていません
 		} else {
 			if ($dir == $this->gEnv->getSystemRootPath()){// このシステムのディレクトリではないか
-				$this->setMsg(self::MSG_APP_ERR, "このシステム自体を指定しています");
+				$this->setMsg(self::MSG_APP_ERR, $this->_('This system selected.'));		// このシステム自体を指定しています
 			} else if (!is_file($dir . '/include/global.php') || !is_file($dir . '/include/siteDef.php')){// Magic3かどうか
-				$this->setMsg(self::MSG_APP_ERR, "Magic3システムを指定していません");
+				$this->setMsg(self::MSG_APP_ERR, $this->_('Magic3 system not selected.'));		// Magic3システムを指定していません
 			}
 		}
 		
