@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installInitotherWidgetContainer.php 3795 2010-11-09 07:12:37Z fishbone $
+ * @version    SVN: $Id: _installInitotherWidgetContainer.php 5095 2012-08-08 13:29:27Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/_installBaseWidgetContainer.php');
@@ -93,6 +93,7 @@ class _installInitotherWidgetContainer extends _installBaseWidgetContainer
 			$this->tmpl->setAttribute('install_msg', 'visibility', 'visible');// テーブル構築完了のメッセージ
 		}
 		// サンプルSQLスクリプトディレクトリのチェック
+		$scriptFiles = array();
 		$searchPath = $this->gEnv->getSqlPath() . '/' . self::SAMPLE_DIR;
 		if (is_dir($searchPath)){
 			$dir = dir($searchPath);
@@ -101,24 +102,32 @@ class _installInitotherWidgetContainer extends _installBaseWidgetContainer
 				// ファイルかどうかチェック
 				if (strncmp($file, '.', 1) != 0 && $file != '..' && is_file($filePath)
 					&& strncmp($file, '_', 1) != 0){	// 「_」で始まる名前のファイルは読み込まない
-					
-					// デフォルトのファイル名を決定
-					if (empty($filename)) $filename = $file;
-					
-					$selected = '';
-					if ($file == $filename){
-						$selected = 'selected';
-					}
-					$row = array(
-						'value'    => $file,			// ファイル名
-						'name'     => $file,			// ファイル名
-						'selected' => $selected														// 選択中かどうか
-					);
-					$this->tmpl->addVars('sample__sql_list', $row);
-					$this->tmpl->parseTemplate('sample__sql_list', 'a');
+					$scriptFiles[] = $file;
 				}
 			}
 			$dir->close();
+			
+			// アルファベット順にソート
+			sort($scriptFiles);
+			
+			// スクリプトをメニューに登録
+			for ($i = 0; $i < count($scriptFiles); $i++){
+				$file = $scriptFiles[$i];
+				
+				// デフォルトのファイル名を決定
+				if (empty($filename)) $filename = $file;
+				
+				$selected = '';
+				if ($file == $filename) $selected = 'selected';
+
+				$row = array(
+					'value'    => $file,			// ファイル名
+					'name'     => $file,			// ファイル名
+					'selected' => $selected														// 選択中かどうか
+				);
+				$this->tmpl->addVars('sample__sql_list', $row);
+				$this->tmpl->parseTemplate('sample__sql_list', 'a');
+			}
 		}
 		// 実行スクリプトファイルのヘッダを取得
 		if (!empty($filename)){
