@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: help_menudef.php 3883 2010-12-07 10:14:56Z fishbone $
+ * @version    SVN: $Id: help_menudef.php 4935 2012-06-05 09:40:47Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCommonPath()				. '/helpConv.php' );
@@ -43,6 +43,10 @@ class help_menudef extends HelpConv
 				'title' =>	$this->_('Name'),			// 名前
 				'body' =>	$this->_('Definition name for menu item.')		// メニュー項目の名前です。
 			),
+			'menudef_lang' => array(	
+				'title' =>	$this->_('Language'),			// 言語
+				'body' =>	$this->_('Language for menu item.')		// メニュー項目の対応言語です。
+			),
 			'menudef_item_type' => array(	
 				'title' =>	$this->_('Menu Item Type'),			// メニュー項目タイプ
 				'body' =>	$this->_('You can select menu item type below.<br /><strong>Link</strong> - Normal link item to go page if selected.<br /><strong>Folder</strong> - Item has sub menu items.<br /><strong>Text</strong> - Text item not to link.<br /><strong>Separator</strong> - Separete between menu items.')		// メニュー項目のタイプです。<br />「リンク」-クリックすると画面遷移する通常のリンク項目です。<br />「フォルダ」-サブメニューを持つ項目です。<br />「テキスト」-画面遷移せず文字列を表示するだけの項目です。<br />「セパレータ」-区切り項目です。
