@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_menu2WidgetContainer.php 3905 2010-12-21 10:45:52Z fishbone $
+ * @version    SVN: $Id: admin_menu2WidgetContainer.php 5113 2012-08-16 00:55:09Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -206,7 +206,7 @@ class admin_menu2WidgetContainer extends BaseAdminWidgetContainer
 				// サイト表示
 				$siteName = $this->gEnv->getSiteName();
 				//if (empty($siteName)) $siteName = self::DEFAULT_SITE_NAME;
-				if (empty($siteName)) $siteName = $this->_('Untitled Site');
+				//if (empty($siteName)) $siteName = $this->_('Untitled Site');
 				$siteUrl = $this->gEnv->getRootUrl();
 				$this->tmpl->addVar("menuvisiblebutton", "site_name", $siteName);
 				$this->tmpl->addVar("menuvisiblebutton", "site", '<label><a href="#" onclick="previewSite(\'' . $siteUrl . '\');">' . $siteUrl . '</a></label>');
