@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_mainTopWidgetContainer.php 5253 2012-09-29 14:11:07Z fishbone $
+ * @version    SVN: $Id: blog_mainTopWidgetContainer.php 5265 2012-10-03 09:36:36Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/blog_mainBaseWidgetContainer.php');
@@ -375,7 +375,13 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 			}
 		}
 
-		self::$_mainDb->getEntryItems($entryViewCount, $this->pageNo, $this->now, $this->entryId, $this->startDt/*期間開始*/, $this->endDt/*期間終了*/, $this->_langId, $entryViewOrder, array($this, 'itemsLoop'));
+		if ($this->gEnv->isSystemManageUser()){		// システム管理ユーザの場合
+			self::$_mainDb->getEntryItems($entryViewCount, $this->pageNo, $this->now, $this->entryId, $this->startDt/*期間開始*/, $this->endDt/*期間終了*/,
+										''/*検索キーワード*/, $this->_langId, $entryViewOrder, array($this, 'itemsLoop'));
+		} else {
+			self::$_mainDb->getEntryItems($entryViewCount, $this->pageNo, $this->now, $this->entryId, $this->startDt/*期間開始*/, $this->endDt/*期間終了*/,
+										''/*検索キーワード*/, $this->_langId, $entryViewOrder, array($this, 'itemsLoop'), null, $this->_userId);
+		}
 
 		// ページのタイトル設定
 		if (!empty($entryRow)) $this->pageTitle = $entryRow['be_name'];		// 記事レコードがあるとき
@@ -413,8 +419,18 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 			if (empty($this->blogId)){
 				$showTopContent = true;
 			} else {
+				// 参照可能なブログかチェック
 				$ret = self::$_mainDb->isActiveBlogInfo($this->blogId);
 				if ($ret){			// ブログ情報が存在するとき
+					// 参照権限をチェック
+					if (!self::$_canEditEntry){		// 記事編集権限なしのとき
+						$ret = self::$_mainDb->isReadableBlogInfo($this->blogId, $this->_userId);
+						if (!$ret) $showTopContent = true;
+					}
+				} else {
+					$showTopContent = true;
+				}
+				if (!$showTopContent){
 					$targetBlogId = $this->blogId;
 					
 					// マルチブログ時のみの処理
@@ -426,8 +442,6 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 						$this->headDesc .= $row['bl_meta_description'];
 						$this->headKeyword .= $row['bl_meta_keywords'];
 					}
-				} else {
-					$showTopContent = true;
 				}
 			}
 		}
@@ -444,17 +458,26 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 		}
 		if (!$showTopContent){
 			// 総数を取得
-			$totalCount = self::$_mainDb->getEntryItemsCount($this->now, $this->startDt, $this->endDt, $this->_langId, $targetBlogId);
+			if ($this->gEnv->isSystemManageUser()){		// システム管理ユーザの場合
+				$totalCount = self::$_mainDb->getEntryItemsCount($this->now, $this->startDt, $this->endDt, ''/*検索キーワード*/, $this->_langId, $targetBlogId);
+			} else {
+				$totalCount = self::$_mainDb->getEntryItemsCount($this->now, $this->startDt, $this->endDt, ''/*検索キーワード*/, $this->_langId, $targetBlogId, $this->_userId);
+			}
 
 			// リンク文字列作成、ページ番号調整
 			// マルチブログのときはブログIDを付加する
 			$multiBlogParam = '';		// マルチブログ時の追加パラメータ
 			if ($this->useMultiBlog) $multiBlogParam = '&' . M3_REQUEST_PARAM_BLOG_ID . '=' . $targetBlogId;
 			$pageLink = $this->createPageLink($this->pageNo, $totalCount, $entryViewCount, $this->currentPageUrl . $multiBlogParam);
-		
+
 			// 記事一覧作成
-			self::$_mainDb->getEntryItems($entryViewCount, $this->pageNo, $this->now, 0/* 期間で指定 */, $this->startDt/*期間開始*/, $this->endDt/*期間終了*/,
-							$this->_langId, $entryViewOrder, array($this, 'itemsLoop'), $targetBlogId);
+			if ($this->gEnv->isSystemManageUser()){		// システム管理ユーザの場合
+				self::$_mainDb->getEntryItems($entryViewCount, $this->pageNo, $this->now, 0/*期間で指定*/, $this->startDt/*期間開始*/, $this->endDt/*期間終了*/,
+								''/*検索キーワード*/, $this->_langId, $entryViewOrder, array($this, 'itemsLoop'), $targetBlogId);
+			} else {
+				self::$_mainDb->getEntryItems($entryViewCount, $this->pageNo, $this->now, 0/*期間で指定*/, $this->startDt/*期間開始*/, $this->endDt/*期間終了*/,
+								''/*検索キーワード*/, $this->_langId, $entryViewOrder, array($this, 'itemsLoop'), $targetBlogId, $this->_userId);
+			}
 			
 			if ($this->isExistsViewData){
 				// ページリンクを埋め込む
@@ -501,14 +524,27 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 			}
 			
 			// 総数を取得
-			$totalCount = self::$_mainDb->searchEntryItemsCountByKeyword($this->now, $parsedKeywords, $this->_langId);
+			if ($this->gEnv->isSystemManageUser()){		// システム管理ユーザの場合
+				//$totalCount = self::$_mainDb->searchEntryItemsCountByKeyword($this->now, $parsedKeywords, $this->_langId);
+				$totalCount = self::$_mainDb->getEntryItemsCount($this->now, ''/*期間開始*/, ''/*期間終了*/, $parsedKeywords, $this->_langId, null/*ブログID*/);
+			} else {
+				//$totalCount = self::$_mainDb->searchEntryItemsCountByKeyword($this->now, $parsedKeywords, $this->_langId, $this->_userId);
+				$totalCount = self::$_mainDb->getEntryItemsCount($this->now, ''/*期間開始*/, ''/*期間終了*/, $parsedKeywords, $this->_langId, null/*ブログID*/, $this->_userId);
+			}
 
 			// リンク文字列作成、ページ番号調整
 			$pageLink = $this->createPageLink($this->pageNo, $totalCount, $entryViewCount, $this->currentPageUrl . '&act=search&keyword=' . urlencode($keyword));
 			
 			// 記事一覧を表示
-			//self::$_mainDb->searchEntryItemsByKeyword($entryViewCount, $this->pageNo, $this->now, $parsedKeywords, $this->_langId, array($this, 'searchItemsLoop'));
-			self::$_mainDb->searchEntryItemsByKeyword($entryViewCount, $this->pageNo, $this->now, $parsedKeywords, $this->_langId, array($this, 'itemsLoop'));
+			if ($this->gEnv->isSystemManageUser()){		// システム管理ユーザの場合
+				//self::$_mainDb->searchEntryItemsByKeyword($entryViewCount, $this->pageNo, $this->now, $parsedKeywords, $this->_langId, array($this, 'itemsLoop'));
+				self::$_mainDb->getEntryItems($entryViewCount, $this->pageNo, $this->now, 0, ''/*期間開始*/, ''/*期間終了*/,
+													$parsedKeywords, $this->_langId, $entryViewOrder, array($this, 'itemsLoop'), null/*ブログID*/);
+			} else {
+				//self::$_mainDb->searchEntryItemsByKeyword($entryViewCount, $this->pageNo, $this->now, $parsedKeywords, $this->_langId, array($this, 'itemsLoop'), $this->_userId);
+				self::$_mainDb->getEntryItems($entryViewCount, $this->pageNo, $this->now, 0, ''/*期間開始*/, ''/*期間終了*/,
+													$parsedKeywords, $this->_langId, $entryViewOrder, array($this, 'itemsLoop'), null/*ブログID*/, $this->_userId);
+			}
 			
 			if ($this->isExistsViewData){
 				// ページリンクを埋め込む
@@ -550,13 +586,21 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 		}*/
 		if (!empty($category)){				// カテゴリー指定のとき
 			// 総数を取得
-			$totalCount = self::$_mainDb->getEntryItemsCountByCategory($this->now, $category, $this->_langId);
+			if ($this->gEnv->isSystemManageUser()){		// システム管理ユーザの場合
+				$totalCount = self::$_mainDb->getEntryItemsCountByCategory($this->now, $category, $this->_langId);
+			} else {
+				$totalCount = self::$_mainDb->getEntryItemsCountByCategory($this->now, $category, $this->_langId, $this->_userId);
+			}
 
 			// リンク文字列作成、ページ番号調整
 			$pageLink = $this->createPageLink($this->pageNo, $totalCount, $entryViewCount, $this->currentPageUrl . '&act=view&' . M3_REQUEST_PARAM_CATEGORY_ID . '=' . $category);
 			
 			// 記事一覧を表示
-			self::$_mainDb->getEntryItemsByCategory($entryViewCount, $this->pageNo, $this->now, $category, $this->_langId, $entryViewOrder, array($this, 'itemsLoop'));
+			if ($this->gEnv->isSystemManageUser()){		// システム管理ユーザの場合
+				self::$_mainDb->getEntryItemsByCategory($entryViewCount, $this->pageNo, $this->now, $category, $this->_langId, $entryViewOrder, array($this, 'itemsLoop'));
+			} else {
+				self::$_mainDb->getEntryItemsByCategory($entryViewCount, $this->pageNo, $this->now, $category, $this->_langId, $entryViewOrder, array($this, 'itemsLoop'), $this->_userId);
+			}
 
 			// タイトルの設定
 			$ret = $this->categoryDb->getCategoryByCategoryId($category, $this->gEnv->getDefaultLanguage(), $row);
@@ -579,14 +623,24 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 				$endDt = $this->getNextMonth($year . '/' . $month) . '/1';
 				
 				// 総数を取得
-				$totalCount = self::$_mainDb->getEntryItemsCount($this->now, $startDt, $endDt, $this->_langId);
+				if ($this->gEnv->isSystemManageUser()){		// システム管理ユーザの場合
+					$totalCount = self::$_mainDb->getEntryItemsCount($this->now, $startDt, $endDt, ''/*検索キーワード*/, $this->_langId);
+				} else {
+					$totalCount = self::$_mainDb->getEntryItemsCount($this->now, $startDt, $endDt, ''/*検索キーワード*/, $this->_langId, null, $this->_userId);
+				}
 
 				// リンク文字列作成、ページ番号調整
 				$pageLink = $this->createPageLink($this->pageNo, $totalCount, $entryViewCount, $this->currentPageUrl . '&act=view&year=' . $year . '&month=' . $month);
 			
 				// 記事一覧作成
-				self::$_mainDb->getEntryItems($entryViewCount, $this->pageNo, $this->now, $this->entryId, $startDt/*期間開始*/, $endDt/*期間終了*/, $this->_langId, $entryViewOrder, array($this, 'itemsLoop'));
-
+				if ($this->gEnv->isSystemManageUser()){		// システム管理ユーザの場合
+					self::$_mainDb->getEntryItems($entryViewCount, $this->pageNo, $this->now, 0/*期間で指定*/, $startDt/*期間開始*/, $endDt/*期間終了*/,
+													''/*検索キーワード*/, $this->_langId, $entryViewOrder, array($this, 'itemsLoop'));
+				} else {
+					self::$_mainDb->getEntryItems($entryViewCount, $this->pageNo, $this->now, 0/*期間で指定*/, $startDt/*期間開始*/, $endDt/*期間終了*/,
+													''/*検索キーワード*/, $this->_langId, $entryViewOrder, array($this, 'itemsLoop'), null, $this->_userId);
+				}
+				
 				if ($this->isExistsViewData){
 					// ページリンクを埋め込む
 					if (!empty($pageLink)){
@@ -606,13 +660,23 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 				$endDt = $this->getNextDay($year . '/' . $month . '/' . $day);
 				
 				// 総数を取得
-				$totalCount = self::$_mainDb->getEntryItemsCount($this->now, $startDt, $endDt, $this->_langId);
+				if ($this->gEnv->isSystemManageUser()){		// システム管理ユーザの場合
+					$totalCount = self::$_mainDb->getEntryItemsCount($this->now, $startDt, $endDt, ''/*検索キーワード*/, $this->_langId);
+				} else {
+					$totalCount = self::$_mainDb->getEntryItemsCount($this->now, $startDt, $endDt, ''/*検索キーワード*/, $this->_langId, null, $this->_userId);
+				}
 
 				// リンク文字列作成、ページ番号調整
 				$pageLink = $this->createPageLink($this->pageNo, $totalCount, $entryViewCount, $this->currentPageUrl . '&act=view&year=' . $year . '&month=' . $month . '&day=' . $day);
 				
 				// 記事一覧作成
-				self::$_mainDb->getEntryItems($entryViewCount, $this->pageNo, $this->now, $this->entryId, $startDt/*期間開始*/, $endDt/*期間終了*/, $this->_langId, $entryViewOrder, array($this, 'itemsLoop'));
+				if ($this->gEnv->isSystemManageUser()){		// システム管理ユーザの場合
+					self::$_mainDb->getEntryItems($entryViewCount, $this->pageNo, $this->now, 0/*期間で指定*/, $startDt/*期間開始*/, $endDt/*期間終了*/,
+													''/*検索キーワード*/, $this->_langId, $entryViewOrder, array($this, 'itemsLoop'));
+				} else {
+					self::$_mainDb->getEntryItems($entryViewCount, $this->pageNo, $this->now, 0/*期間で指定*/, $startDt/*期間開始*/, $endDt/*期間終了*/,
+													''/*検索キーワード*/, $this->_langId, $entryViewOrder, array($this, 'itemsLoop'), null, $this->_userId);
+				}
 				
 				if ($this->isExistsViewData){
 					// ページリンクを埋め込む
