@@ -10,7 +10,7 @@
  * @author     株式会社 毎日メディアサービス
  * @copyright  Copyright 2010-2011 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: custom_searchWidgetContainer.php 4029 2011-03-15 03:51:41Z fishbone $
+ * @version    SVN: $Id: custom_searchWidgetContainer.php 4454 2011-11-14 23:15:30Z fishbone $
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -117,21 +117,15 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 		
 		if ($act == self::DEFAULT_SEARCH_ACT){		// 検索実行
 			// 検索キーワードが空以外の場合は、キーワードログを残す
+			$parsedKeywords = array();
 			if (!empty($keyword)){
-				/*
-				// スペース区切りの場合はワードを分割
-								
-				// 全角英数を半角に、半角カナ全角ひらがなを全角カナに変換
-				$basicWord = $keyword;
-				if (function_exists('mb_convert_kana')) $basicWord = mb_convert_kana($basicWord, 'aKCV');
-				$basicWord = strtolower($basicWord);		// 大文字を小文字に変換
+				// キーワード分割
+				$parsedKeywords = $this->gInstance->getTextConvManager()->parseSearchKeyword($keyword);
 				
-				// 検索キーワードログ書き込み
-				$cid = $this->gAccess->getClientId();// クッキー値のクライアントID
-				$this->db->writeKeywordLog($cid, $this->gEnv->getCurrentWidgetId(), $keyword, $basicWord);
-				*/
 				// 検索キーワードを記録
-				$this->gInstance->getAnalyzeManager()->logSearchWord($this->gEnv->getCurrentWidgetId(), $keyword);
+				for ($i = 0; $i < count($parsedKeywords); $i++){
+					$this->gInstance->getAnalyzeManager()->logSearchWord($this->gEnv->getCurrentWidgetId(), $parsedKeywords[$i]);
+				}
 			}
 			
 			// カテゴリの設定値を取得
@@ -146,13 +140,13 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 				if (!empty($inputValue)) $selectCategory[$categoryType] = $inputValue;		// 入力値
 			}
 			// 総数を取得
-			$totalCount = $this->db->searchContentsCountByKeyword($keyword, $selectCategory, $this->langId, $isTargetContent, $isTargetUser, $isTargetBlog);
+			$totalCount = $this->db->searchContentsCountByKeyword($parsedKeywords, $selectCategory, $this->langId, $isTargetContent, $isTargetUser, $isTargetBlog);
 
 			// リンク文字列作成、ページ番号調整
 			$pageLink = $this->createPageLink($pageNo, $totalCount, $this->resultCount, $this->currentPageUrl . '&act=' . self::DEFAULT_SEARCH_ACT . '&keyword=' . urlencode($keyword));
 				
 			// 検出項目を表示
-			$this->db->searchContentsByKeyword($this->resultCount, $pageNo, $keyword, $selectCategory, $this->langId, $isTargetContent, $isTargetUser, $isTargetBlog, array($this, 'searchItemsLoop'));
+			$this->db->searchContentsByKeyword($this->resultCount, $pageNo, $parsedKeywords, $selectCategory, $this->langId, $isTargetContent, $isTargetUser, $isTargetBlog, array($this, 'searchItemsLoop'));
 				
 			if ($this->isExistsViewData){
 				// ページリンクを埋め込む
