@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_contentCommonDef.php 5102 2012-08-11 07:54:51Z fishbone $
+ * @version    SVN: $Id: default_contentCommonDef.php 5135 2012-08-23 09:18:15Z fishbone $
  * @link       http://www.magic3.org
  */
  
@@ -32,7 +32,7 @@ class default_contentCommonDef
 	const ATTACH_FILE_DIR = '/etc/content';				// 添付ファイル格納ディレクトリ
 	const DOWNLOAD_CONTENT_TYPE = '-file';				// ダウンロードするコンテンツのタイプ
 	const DEFAULT_CONTENT_LAYOUT = '[#BODY#][#FILES#][#PAGES#][#LINKS#]';	// デフォルトのコンテンツレイアウト
-	const DEFAULT_HEAD_VIEW_DETAIL = '<meta property="og:type" content="article" /><meta property="og:title" content="[#CT_TITLE#]" /><meta property="og:url" content="[#CT_URL#]" /><meta property="og:description" content="[#CT_DESCRIPTION#]" /><meta property="og:site_name" content="[#SITE_NAME#]" />';	// デフォルトのヘッダ出力(詳細表示)
+	const DEFAULT_HEAD_VIEW_DETAIL = '<meta property="og:type" content="article" /><meta property="og:title" content="[#CT_TITLE#]" /><meta property="og:url" content="[#CT_URL#]" /><meta property="og:image" content="[#CT_IMAGE#]" /><meta property="og:description" content="[#CT_DESCRIPTION#]" /><meta property="og:site_name" content="[#SITE_NAME#]" />';	// デフォルトのヘッダ出力(詳細表示)
 	
 	/**
 	 * フォトギャラリー定義値をDBから取得
