@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_dispProductWidgetContainer.php 5398 2012-11-22 02:29:37Z fishbone $
+ * @version    SVN: $Id: ec_dispProductWidgetContainer.php 5419 2012-11-30 05:06:11Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -157,15 +157,16 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 				
 		// パラメータを取得
 		// カテゴリーを取得
-		$this->categoryId = $request->trimValueOf('category');	// カテゴリーID
-		$categoryArray = explode(',', $this->categoryId);
+		$categoryId = $request->trimValueOf('category');	// カテゴリーID
+		$this->categoryId = $categoryId;
+		$categoryArray = explode(',', $categoryId);
 		if (!ValueCheck::isNumeric($categoryArray)){
-			$this->categoryId = '';		// すべて数値であるかチェック
+			$categoryId = '';		// すべて数値であるかチェック
 			$categoryArray = array();
 		}
 		if (!empty($categoryArray) && $this->ecObj->getConfig(self::CF_E_HIERARCHICAL_CATEGORY)){			// サブカテゴリーを取得する場合
 			$categoryArray = array_unique($this->getSubCategory($categoryArray));
-			$this->categoryId = implode(',', $categoryArray);
+			$categoryId = implode(',', $categoryArray);
 		}
 		
 		$pageNo = $request->trimValueOf(M3_REQUEST_PARAM_PAGE_NO);				// ページ番号
@@ -316,9 +317,9 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 				}
 			} else {
 				// 指定カテゴリーの商品を取得
-				if (!empty($this->categoryId)){
+				if (!empty($categoryId)){
 					// 総数を取得
-					$totalCount = $this->db->getProductCountByCategoryId($this->categoryId, $this->langId);
+					$totalCount = $this->db->getProductCountByCategoryId($categoryId, $this->langId);
 					$pageCount = (int)(($totalCount -1) / $productCount) + 1;		// 総ページ数
 			
 					// 表示するページ番号の修正
@@ -326,15 +327,14 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 					if ($pageNo > $pageCount) $pageNo = $pageCount;
 
 					// 商品リストを表示
-					$this->db->getProductByCategoryId($this->categoryId, $this->langId, $productCount, ($pageNo -1) * $productCount, array($this, 'productListLoop'));
+					$this->db->getProductByCategoryId($categoryId, $this->langId, $productCount, ($pageNo -1) * $productCount, array($this, 'productListLoop'));
 
 					// ページング用リンク作成
-					// カテゴリーはアクセス時のパラメータを使用
-					$categoryId = $request->trimValueOf('category');	// カテゴリーID
+					// ##### カテゴリーはアクセス時のパラメータを使用 #####
 					$pageLink = '';
 					if ($pageCount > 1){	// ページが2ページ以上のときリンクを作成
 						for ($i = 1; $i <= $pageCount; $i++){
-							$linkUrl = $this->currentPageUrl . '&category=' . $categoryId . '&page=' . $i;
+							$linkUrl = $this->currentPageUrl . '&category=' . $this->categoryId . '&page=' . $i;
 							if ($i == $pageNo){
 								$link = '&nbsp;' . $i;
 							} else {
@@ -352,7 +352,7 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 				// 商品があるかチェック
 				if ($this->productExists) $this->tmpl->setAttribute('show_productlist', 'visibility', 'visible');
 				// 登録項目がないとき
-				if (!empty($this->categoryId) && !$this->subcategoryExists && !$this->productExists){
+				if (!empty($categoryId) && !$this->subcategoryExists && !$this->productExists){
 					$this->tmpl->setAttribute('no_item_message', 'visibility', 'visible');
 					$this->tmpl->addVar("no_item_message", "detail", '項目がありません');// 詳細
 				}
@@ -579,8 +579,10 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 		
 		// 商品詳細リンクを作成
 		$name = '詳細';		// 名前
-		//$linkUrl = $this->currentPageUrl . '&product=' . $row['pt_id'];
-		$linkUrl = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_PRODUCT_ID . '=' . $row['pt_id'];
+		//$linkUrl = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_PRODUCT_ID . '=' . $row['pt_id'];
+		$linkUrl = $this->currentPageUrl;
+		if (!empty($this->categoryId)) $linkUrl .= '&category=' . $this->categoryId;
+		$linkUrl .= '&' . M3_REQUEST_PARAM_PRODUCT_ID . '=' . $row['pt_id'];
 		$link = '<a href="' . $this->getUrl($linkUrl, true) . '" >' . $name . '</a>';
 		
 		// 画像にリンクを付ける
