@@ -1,6 +1,6 @@
 <?php
 /**
- * コンテナクラス
+ * index.php用コンテナクラス
  *
  * PHP versions 5
  *
@@ -8,52 +8,47 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_mainMemberWidgetContainer.php 2623 2009-12-05 12:40:38Z fishbone $
+ * @version    SVN: $Id: admin_ec_mainMemberWidgetContainer.php 5440 2012-12-08 09:37:39Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_ec_mainBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/ec_mainMemberDb.php');
-require_once($gEnvManager->getCurrentWidgetDbPath() .	'/ec_mainDb.php');
 
 class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $mainDb;	// DB接続オブジェクト
-	private $sysDb;		// システムDBオブジェクト
 	private $serialNo;			// シリアル番号
 	private $firstNo;			// 項目番号
 	private $state;				// 都道府県
 	private $memberType;		// 会員タイプ
 	private $ecMailObj;	// メール連携オブジェクト
 	private $serialArray = array();		// 表示されている項目シリアル番号
+	private $gender;			// 性別
 	const EC_LIB_ID = "eclib";		// EC共通ライブラリオブジェクトID
 	const DEFAULT_COUNTRY_ID = 'JPN';	// デフォルト国ID
 	const DEFAULT_LIST_COUNT = 20;			// 最大リスト表示数
 	const USE_EMAIL		= 'use_email';		// EMAIL機能が使用可能かどうか
-	const SEND_PASSWORD_FORM = 'send_password';		// パスワード送信用フォーム
+//	const SEND_PASSWORD_FORM = 'send_password';		// パスワード送信用フォーム
 	const AUTO_EMAIL_SENDER	= 'auto_email_sender';		// 自動送信メール用送信者アドレス
 	const MAIL_OBJ_ID = 'ecmail';			// メール連携オブジェクト
 	const TARGET_WIDGET = 'ec_main';		// パスワード送信後にログインするための画面呼び出しウィジェットID
-		
+	const PERSON_INFO_OPT_SPORTS = 'sports';		// 個人情報オプション(現在やっているスポーツ)
+	
 	/**
 	 * コンストラクタ
 	 */
 	function __construct()
 	{
-		global $gInstanceManager;
-		
 		// 親クラスを呼び出す
 		parent::__construct();
 		
 		// DBオブジェクト作成
 		$this->db = new ec_mainMemberDb();
-		$this->mainDb = new ec_mainDb();
-		$this->sysDb = $gInstanceManager->getSytemDbObject();
 		
 		// メール連携オブジェクト取得
-		$this->ecMailObj = $gInstanceManager->getObject(self::MAIL_OBJ_ID);
+		$this->ecMailObj = $this->gInstance->getObject(self::MAIL_OBJ_ID);
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -100,15 +95,13 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 	 */
 	function createList($request)
 	{
-		global $gEnvManager;
-		
 		$pageNo = $request->trimValueOf('page');				// ページ番号
 		if (empty($pageNo)) $pageNo = 1;
 		$this->memberType	= $request->trimValueOf('member_type');				// 会員タイプ
 		
 		// デフォルト値を取得
 		$maxListCount = self::DEFAULT_LIST_COUNT;
-		$serializedParam = $this->sysDb->getWidgetParam($gEnvManager->getCurrentWidgetId());
+		$serializedParam = $this->_db->getWidgetParam($this->gEnv->getCurrentWidgetId());
 		if (!empty($serializedParam)){
 			$dispInfo = unserialize($serializedParam);
 			$maxListCount = $dispInfo->maxMemberListCountByAdmin;		// 会員リスト最大表示数
@@ -127,7 +120,6 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 				}
 			}
 			if (count($delItems) > 0){
-				//$ret = $this->db->deleteDelivMethodDefBySerial($delItems);
 				for ($i = 0; $i < count($delItems); $i++){
 					$ret = $this->deleteUser($delItems[$i]);
 					if (!$ret) break;
@@ -169,6 +161,7 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 			// 仮会員リストを表示
 			$this->db->getMemberList(1, $maxListCount, ($pageNo -1) * $maxListCount, array($this, 'memberListLoop'));
 		}
+		if (empty($this->serialArray)) $this->tmpl->setAttribute('itemlist', 'visibility', 'hidden');// 会員リストがないときは、一覧を表示しない
 		
 		// ページング用リンク作成
 		$pageLink = '';
@@ -197,15 +190,8 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 	 */
 	function createDetail($request)
 	{
-		global $gEnvManager;
-		global $gSystemManager;
-		global $gInstanceManager;
-		global $gPageManager;
-
 		// ユーザ情報、表示言語
 		$now = date("Y/m/d H:i:s");	// 現在日時
-		$userId		= $gEnvManager->getCurrentUserId();
-		$langId	= $gEnvManager->getCurrentLanguage();		// 表示言語を取得
 		$countryId = self::DEFAULT_COUNTRY_ID;			// デフォルト国ID
 				
 		$act = $request->trimValueOf('act');
@@ -214,9 +200,6 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 		$memberNo			= $request->trimValueOf('member_no');			// 会員No
 		$email				= $request->trimValueOf('email');			// eメール(ログインアカウント)
 		$mobile				= $request->trimValueOf('mobile');			// 携帯電話
-		$gender				= $request->trimValueOf('gender');			// 性別
-		$birthday			= $request->trimValueOf('birthday');
-		if (!empty($birthday)) $birthday = $this->convertToProperDate($birthday);			// 生年月日
 		$familyName			= $request->trimValueOf('family_name');		// 会員名(姓)
 		$firstName			= $request->trimValueOf('first_name');		// 会員名(名)
 		$familyNameKana		= $request->trimValueOf('family_name_kana');		// 会員名カナ(姓)
@@ -227,6 +210,15 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 		$address2			= $request->trimValueOf('address2');			// 住所2
 		$phone				= $request->trimValueOf('phone');			// 電話番号
 		$fax				= $request->trimValueOf('fax');				// FAX
+		
+		// フォトギャラリー追加分
+		if (photo_shopCommonDef::MEMBER_INFO_OPTION){
+			$this->gender			= $request->trimValueOf('gender');			// 性別
+			$birthday			= $request->trimValueOf('birthday');
+			if (!empty($birthday)) $birthday = $this->convertToProperDate($birthday);			// 生年月日
+			$sports = $request->trimValueOf('item_sports');			// 現在やってるスポーツ
+		}
+		
 		//$withLoginUser		= ($request->trimValueOf('withloginuser') == 'on') ? 1 : 0;		// ログインアカウントも削除するかどうか
 		$withLoginUser = 1;			// 常にログインアカウントは削除に設定
 				
@@ -238,10 +230,14 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 			$this->checkInput($familyNameKana, '会員名カナ(姓)');
 			$this->checkInput($firstNameKana, '会員名カナ(名)');
 			$this->checkMailAddress($email, 'Eメール');
-			$this->checkDate($birthday, '生年月日', true);
+			
+			// フォトギャラリー追加分
+			if (photo_shopCommonDef::MEMBER_INFO_OPTION){
+				$this->checkDate($birthday, '生年月日', true);
+			}
 			
 			// メールアドレスが登録済みかチェック
-			if ($this->sysDb->isExistsAccount($email)){// メールアドレスがログインIDとして既に登録されているかチェック
+			if ($this->_db->isExistsAccount($email)){// メールアドレスがログインIDとして既に登録されているかチェック
 				$this->setAppErrorMsg('このEメールアドレスは既に登録されています');
 			}
 			// 会員NOの重複チェック
@@ -258,17 +254,24 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 				$this->db->startTransaction();
 
 				// ログインユーザを作成
-				$ret = $this->db->addUser(1/* 正会員 */, $familyName . $firstName, $email, $password, $gEnvManager->getCurrentWidgetId(), $userId, $now, $loginUserId);		// 新規ログインユーザIDを取得
+				$ret = $this->db->addUser(1/* 正会員 */, $familyName . $firstName, $email, $password, $this->gEnv->getCurrentWidgetId(), $this->_userId, $now, $loginUserId);		// 新規ログインユーザIDを取得
 
 				// 住所登録
-				if ($ret) $ret = $this->db->updateAddress(0, $langId, '', $zipcode, $this->state, $address, $address2, $phone, $fax, $countryId, $userId, $now, $addressId);
+				if ($ret) $ret = $this->db->updateAddress(0, $this->_langId, '', $zipcode, $this->state, $address, $address2, $phone, $fax, $countryId, $this->_userId, $now, $addressId);
 
 				// 個人情報登録
-				if (empty($birthday)) $birthday = $gEnvManager->getInitValueOfTimestamp();
-				if ($ret) $ret = $this->db->updatePersonInfo(0, $langId, $firstName, $familyName, $firstNameKana, $familyNameKana, $gender, $birthday, $email, $mobile, $addressId, $userId, $now, $personalInfoId);
+				$personOptions = array();
+				if (photo_shopCommonDef::MEMBER_INFO_OPTION){
+					$personOptions[self::PERSON_INFO_OPT_SPORTS] = $sports;
+					if (empty($birthday)) $birthday = $this->gEnv->getInitValueOfDate();
+				} else {
+					$birthday = $this->gEnv->getInitValueOfDate();
+					$this->gender = 0;
+				}
+				if ($ret) $ret = $this->db->updatePersonInfo(0, $this->_langId, $firstName, $familyName, $firstNameKana, $familyNameKana, $this->gender, $birthday, $email, $mobile, $addressId, $this->_userId, $now, $personalInfoId, $personOptions);
 
 				// 会員情報を登録
-				if ($ret) $ret = $this->db->updateMember(0, $langId, 1/* 個人 */, 0/* 法人情報ID */, $personalInfoId, $memberNo, $loginUserId, $userId, $now, $newSerial);
+				if ($ret) $ret = $this->db->updateMember(0, $this->_langId, 1/* 個人 */, 0/* 法人情報ID */, $personalInfoId, $memberNo, $loginUserId, $this->_userId, $now, $newSerial);
 
 				// トランザクション終了
 				$ret = $this->db->endTransaction();
@@ -283,7 +286,7 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 					$this->tmpl->addVar("_widget", "pwd_message", '新規パスワード: ' . $password);
 					
 					// ######## 会員登録のメールをイントラネット側に送信 ########
-					//$stateName = $this->db->getStateName('JPN', $langId, $this->state);			// 都道府県
+					//$stateName = $this->db->getStateName('JPN', $this->_langId, $this->state);			// 都道府県
 					//$address1 = $stateName . $address;
 					//$this->sendMailToBackoffice(0/*新規登録*/, $memberNo, $email, $familyName . $firstName, $familyNameKana . $firstNameKana, $zipcode, $address1, $address2, $phone);
 					$this->ecMailObj->sendMemberInfoToBackoffice(0/*新規登録*/, $loginUserId);
@@ -308,22 +311,36 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 				if ($ret){
 					$personId = $row['sm_person_info_id'];
 					$loginUserId = $row['sm_login_user_id'];
-					$ret = $this->db->getPersonInfo($personId, $row);
+					$ret = $this->db->getPersonInfo($personId, $row, $personOptions);
 					if ($ret){
 						$addressId = $row['pi_address_id'];
 						$email = $row['pi_email'];
 					}
 				}
 				// 住所登録
-				if ($ret) $ret = $this->db->updateAddress($addressId, $langId, '', $zipcode, $this->state, $address, $address2, $phone, $fax, $countryId, $userId, $now, $addressId);
+				if ($ret) $ret = $this->db->updateAddress($addressId, $this->_langId, '', $zipcode, $this->state, $address, $address2, $phone, $fax, $countryId, $this->_userId, $now, $addressId);
 
 				// 個人情報登録
-				if (empty($birthday)) $birthday = $gEnvManager->getInitValueOfTimestamp();
-				if ($ret) $ret = $this->db->updatePersonInfo($personId, $langId, $firstName, $familyName, $firstNameKana, $familyNameKana, $gender, $birthday, $email, $mobile, $addressId, $userId, $now, $personalInfoId);
+				$personOptions = array();
+				if (photo_shopCommonDef::MEMBER_INFO_OPTION){
+					$personOptions[self::PERSON_INFO_OPT_SPORTS] = $sports;
+					if (empty($birthday)) $birthday = $this->gEnv->getInitValueOfDate();
+				} else {
+					$birthday = $this->gEnv->getInitValueOfDate();
+					$this->gender = 0;
+				}
+				if ($ret) $ret = $this->db->updatePersonInfo($personId, $this->_langId, $firstName, $familyName, $firstNameKana, $familyNameKana, $this->gender, $birthday, $email, $mobile, $addressId, $this->_userId, $now, $personalInfoId, $personOptions);
 
 				// 会員情報更新
-				if ($ret) $this->db->updateMember($this->serialNo, $langId, 1/* 個人 */, 0/* 法人情報ID */, $personalInfoId, $memberNo, $loginUserId, $userId, $now, $newSerial);
+				if ($ret) $ret = $this->db->updateMember($this->serialNo, $this->_langId, 1/* 個人 */, 0/* 法人情報ID */, $personalInfoId, $memberNo, $loginUserId, $this->_userId, $now, $newSerial);
 			
+				// ### ログインユーザ名を更新 ###
+				if ($ret){
+					$fieldArray = array();
+					$fieldArray['lu_name'] = $familyName . $firstName;		// 名前を更新
+					$ret = $this->_db->updateLoginUserByField($loginUserId, $fieldArray, $newSerial);
+				}
+				
 				// トランザクション終了
 				$ret = $this->db->endTransaction();
 				if ($ret){
@@ -334,7 +351,7 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 					$replaceNew = true;			// 会員情報を再取得
 					
 					// ######## 会員登録のメールをイントラネット側に送信 ########
-					//$stateName = $this->db->getStateName('JPN', $langId, $this->state);			// 都道府県
+					//$stateName = $this->db->getStateName('JPN', $this->_langId, $this->state);			// 都道府県
 					//$address1 = $stateName . $address;
 					//$this->sendMailToBackoffice(1/*更新*/, $memberNo, $email, $familyName . $firstName, $familyNameKana . $firstNameKana, $zipcode, $address1, $address2, $phone);
 					$this->ecMailObj->sendMemberInfoToBackoffice(1/*更新*/, $loginUserId);
@@ -348,21 +365,6 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 			}
 			// エラーなしの場合は、データを削除
 			if ($this->getMsgCount() == 0){
-				/*
-				// ログインユーザIDを取得
-				if (empty($this->memberType)){		// 正会員のとき
-					if ($this->db->getMemberBySerial(0, $this->serialNo, $row)) $loginUserId = $row['sm_login_user_id'];
-				} else {
-					if ($this->db->getMemberBySerial(1, $this->serialNo, $row)) $loginUserId = $row['sb_login_user_id'];
-				}
-				if (empty($this->memberType)){		// 正会員のとき
-					$ret = $this->db->delMemberBySerial(0, $this->serialNo);
-				} else {
-					$ret = $this->db->delMemberBySerial(1, $this->serialNo);
-				}
-				if ($withLoginUser){		// ログインユーザも削除のとき
-					if ($ret) $this->sysDb->delLoginUser($loginUserId);
-				}*/
 				$ret = $this->deleteUser($this->serialNo);
 				if ($ret){		// データ削除成功のとき
 					$this->setGuidanceMsg('データを削除しました');
@@ -375,7 +377,7 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 			}
 		} else if ($act == 'search'){		// 検索再実行
 		} else if ($act == 'sendpassword'){	// パスワードを送信
-			$useEmail = $this->mainDb->getConfig(self::USE_EMAIL);
+			$useEmail = self::$_mainDb->getConfig(self::USE_EMAIL);
 			if ($useEmail == '1'){		// メール送信可能のとき
 				// 登録済み会員情報を取得
 				if (empty($this->memberType)){		// 正会員のとき
@@ -393,18 +395,19 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 					$password = $this->makePassword();// パスワード作成
 					
 					// パスワード変更
-					$ret = $this->sysDb->updateLoginUserPassword($loginUserId, $password);
+					$ret = $this->_db->updateLoginUserPassword($loginUserId, $password);
 					if ($ret){
-						$fromAddress = $this->mainDb->getConfig(self::AUTO_EMAIL_SENDER);	// 自動送信送信元
-						if (empty($fromAddress)) $fromAddress = $gEnvManager->getSiteEmail();// 送信元が取得できないときは、システムのデフォルトメールアドレスを使用
+						$fromAddress = self::$_mainDb->getConfig(self::AUTO_EMAIL_SENDER);	// 自動送信送信元
+						if (empty($fromAddress)) $fromAddress = $this->gEnv->getSiteEmail();// 送信元が取得できないときは、システムのデフォルトメールアドレスを使用
 						$toAddress = $this->convertToDispString($row['pi_email']);			// eメール(ログインアカウント)
 						$loginParam = 'task=login&act=ec_maillogin&account=' . urlencode($toAddress) . '&pwd=' . urlencode($password);// ログイン用パラメータ
-						//$url = $gPageManager->createWidgetCmdUrl($gEnvManager->getDefaultPageId(), self::TARGET_WIDGET, ''/*送信元ウィジェット指定なし*/, $loginParam);
-						$url = $gPageManager->createWidgetCmdUrl(self::TARGET_WIDGET, ''/*送信元ウィジェット指定なし*/, $loginParam, $gEnvManager->getDefaultPageId());
+						//$url = $this->gPage->createWidgetCmdUrl($this->gEnv->getDefaultPageId(), self::TARGET_WIDGET, ''/*送信元ウィジェット指定なし*/, $loginParam);
+						$url = $this->gPage->createWidgetCmdUrl(self::TARGET_WIDGET, ''/*送信元ウィジェット指定なし*/, $loginParam, $this->gEnv->getDefaultPageId());
 						$mailParam = array();
 						$mailParam['PASSWORD'] = $password;
 						$mailParam['URL']		= $this->getUrl($url, true);		// ログイン用URL
-						$ret = $this->gInstance->getMailManager()->sendFormMail(2/*手動送信*/, $gEnvManager->getCurrentWidgetId(), $toAddress, $fromAddress, '', '', self::SEND_PASSWORD_FORM, $mailParam);// 手動送信
+						$ret = $this->gInstance->getMailManager()->sendFormMail(2/*手動送信*/, $this->gEnv->getCurrentWidgetId(), $toAddress, $fromAddress, '', '',
+																				photo_shopCommonDef::MAIL_FORM_SEND_PASSWORD, $mailParam);// 手動送信
 						
 						// パスワード変更のメッセージ
 						$this->tmpl->addVar("_widget", "pwd_message", '新規パスワード: ' . $password);
@@ -430,8 +433,6 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 					$memberNo = '';			// 会員No
 					$email = '';			// eメール(ログインアカウント)
 					$mobile = '';			// 携帯電話
-					$gender = 0;			// 性別
-					$birthday = '';			// 生年月日
 					$familyName = '';		// 会員名(姓)
 					$firstName = '';		// 会員名(名)
 					$familyNameKana = '';		// 会員名カナ(姓)
@@ -444,9 +445,12 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 					$fax = '';				// FAX
 					$updateUser = '';	// 更新者
 					$updateDt = '';	// 更新日時
+					
+					$this->gender = 0;			// 性別
+					$birthday = '';			// 生年月日
 			
 					// 会員NOのデフォルト値を自動生成
-					$memberNo = $gInstanceManager->getObject(self::EC_LIB_ID)->generateMemberNo();
+					$memberNo = $this->gInstance->getObject(self::EC_LIB_ID)->generateMemberNo();
 				} else {
 					$replaceNew = true;			// 会員情報を再取得
 				}
@@ -468,64 +472,87 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 			}
 			if ($ret){
 				// 取得値を設定
-				$email = $this->convertToDispString($row['pi_email']);			// eメール(ログインアカウント)
-				$mobile = $this->convertToDispString($row['pi_mobile']);			// 携帯電話
-				$gender = $this->convertToDispString($row['pi_gender']);			// 性別
-				$birthday = $this->convertToDispDate($row['pi_birthday']);			// 生年月日
-				if ($birthday == $gEnvManager->getInitValueOfTimestamp()) $birthday = '';
-				$familyName = $this->convertToDispString($row['pi_family_name']);		// 会員名(姓)
-				$firstName = $this->convertToDispString($row['pi_first_name']);		// 会員名(名)
-				$familyNameKana = $this->convertToDispString($row['pi_family_name_kana']);		// 会員名カナ(姓)
-				$firstNameKana = $this->convertToDispString($row['pi_first_name_kana']);		// 会員名カナ(名)
-				$zipcode = $this->convertToDispString($row['ad_zipcode']);				// 郵便番号
+				$email = $row['pi_email'];			// eメール(ログインアカウント)
+				$mobile = $row['pi_mobile'];			// 携帯電話
+				$familyName = $row['pi_family_name'];		// 会員名(姓)
+				$firstName = $row['pi_first_name'];		// 会員名(名)
+				$familyNameKana = $row['pi_family_name_kana'];		// 会員名カナ(姓)
+				$firstNameKana = $row['pi_first_name_kana'];		// 会員名カナ(名)
+				$zipcode = $row['ad_zipcode'];				// 郵便番号
 				$this->state = $row['ad_state_id'];					// 都道府県
-				$address = $this->convertToDispString($row['ad_address1']);			// 住所
-				$address2 = $this->convertToDispString($row['ad_address2']);			// 住所2
-				$phone = $this->convertToDispString($row['ad_phone']);			// 電話番号
-				$fax = $this->convertToDispString($row['ad_fax']);				// FAX				
-				$updateUser = $this->convertToDispString($row['lu_name']);	// 更新者
-					
+				$address = $row['ad_address1'];			// 住所
+				$address2 = $row['ad_address2'];			// 住所2
+				$phone = $row['ad_phone'];			// 電話番号
+				$fax = $row['ad_fax'];				// FAX				
+				$updateUser = $row['lu_name'];	// 更新者
+				if (photo_shopCommonDef::MEMBER_INFO_OPTION){
+					$this->gender = $row['pi_gender'];			// 性別
+					$birthday = $row['pi_birthday'];			// 生年月日
+				}
+				
 				if (empty($this->memberType)){		// 正会員のとき
-					$memberNo = $this->convertToDispString($row['sm_member_no']);			// 会員No
-					$updateDt = $this->convertToDispDateTime($row['sm_create_dt']);	// 更新日時
+					$memberNo = $row['sm_member_no'];			// 会員No
+					$updateDt = $row['sm_create_dt'];	// 更新日時
 				} else {
-					$memberNo = $this->convertToDispString($row['sb_member_no']);			// 会員No
-					$updateDt = $this->convertToDispDateTime($row['sb_create_dt']);	// 更新日時
+					$memberNo = $row['sb_member_no'];			// 会員No
+					$updateDt = $row['sb_create_dt'];	// 更新日時
+				}
+				
+				// 個人情報取得
+				$personId = $row['pi_id'];
+				$ret = $this->db->getPersonInfo($personId, $row, $personOptions);
+				if ($ret){
+					// フォトギャラリー追加分
+					if (photo_shopCommonDef::MEMBER_INFO_OPTION){
+						$sports	= $personOptions[self::PERSON_INFO_OPT_SPORTS];		// 現在やってるスポーツ
+					}
 				}
 			}
 		}
+		// フォトギャラリー追加分
+		if (photo_shopCommonDef::MEMBER_INFO_OPTION){
+			$this->tmpl->setAttribute('script_member_info_option', 'visibility', 'visible');		// スクリプト表示
+			$this->tmpl->setAttribute('show_member_info_option', 'visibility', 'visible');
+		}
+		
 		// 都道府県を設定
-		$this->db->getAllState('JPN', $langId, array($this, 'stateLoop'));
+		$this->db->getAllState('JPN', $this->_langId, array($this, 'stateLoop'));
 		
 		// #### 更新、新規登録部をを作成 ####
-		$this->tmpl->addVar("_widget", "member_no", $memberNo);		// 会員No
-		$this->tmpl->addVar("_widget", "email", $email);		// eメール(ログインアカウント)
-		$this->tmpl->addVar("_widget", "mobile", $mobile);		// 携帯電話
-		//$this->tmpl->addVar("_widget", "gender", $gender);			// 性別
-		$this->tmpl->addVar("_widget", "birthday", $birthday);			// 生年月日
-		$this->tmpl->addVar("_widget", "family_name", $familyName);		// 会員名(姓)
-		$this->tmpl->addVar("_widget", "first_name", $firstName);		// 会員名(名)
-		$this->tmpl->addVar("_widget", "family_name_kana", $familyNameKana);		// 会員名カナ(姓)
-		$this->tmpl->addVar("_widget", "first_name_kana", $firstNameKana);		// 会員名カナ(名)
-		$this->tmpl->addVar("_widget", "zipcode", $zipcode);		// 郵便番号
-		$this->tmpl->addVar("_widget", "address", $address);		// 住所
-		$this->tmpl->addVar("_widget", "address2", $address2);		// 住所2
-		$this->tmpl->addVar("_widget", "phone", $phone);		// 電話番号
-		$this->tmpl->addVar("_widget", "fax", $fax);		// FAX
-		$this->tmpl->addVar("_widget", "update_user", $updateUser);	// 更新者
-		$this->tmpl->addVar("_widget", "update_dt", $updateDt);	// 更新日時
-		// 性別
-		if ($gender == 0){		// 未設定のとき
-			$this->tmpl->addVar("_widget", "gender_none", 'selected');
-		} else if ($gender == 1){
-			$this->tmpl->addVar("_widget", "gender_male", 'selected');
-		} else {
-			$this->tmpl->addVar("_widget", "gender_female", 'selected');
+		$this->tmpl->addVar("_widget", "member_no", $this->convertToDispString($memberNo));		// 会員No
+		$this->tmpl->addVar("_widget", "email", $this->convertToDispString($email));		// eメール(ログインアカウント)
+		$this->tmpl->addVar("_widget", "mobile", $this->convertToDispString($mobile));		// 携帯電話
+		$this->tmpl->addVar("_widget", "family_name", $this->convertToDispString($familyName));		// 会員名(姓)
+		$this->tmpl->addVar("_widget", "first_name", $this->convertToDispString($firstName));		// 会員名(名)
+		$this->tmpl->addVar("_widget", "family_name_kana", $this->convertToDispString($familyNameKana));		// 会員名カナ(姓)
+		$this->tmpl->addVar("_widget", "first_name_kana", $this->convertToDispString($firstNameKana));		// 会員名カナ(名)
+		$this->tmpl->addVar("_widget", "zipcode", $this->convertToDispString($zipcode));		// 郵便番号
+		$this->tmpl->addVar("_widget", "address", $this->convertToDispString($address));		// 住所
+		$this->tmpl->addVar("_widget", "address2", $this->convertToDispString($address2));		// 住所2
+		$this->tmpl->addVar("_widget", "phone", $this->convertToDispString($phone));		// 電話番号
+		$this->tmpl->addVar("_widget", "fax", $this->convertToDispString($fax));		// FAX
+		$this->tmpl->addVar("_widget", "update_user", $this->convertToDispString($updateUser));	// 更新者
+		$this->tmpl->addVar("_widget", "update_dt", $this->convertToDispDateTime($updateDt));	// 更新日時
+		
+		// フォトギャラリー追加分
+		if (photo_shopCommonDef::MEMBER_INFO_OPTION){
+			// 性別
+			if ($this->gender == 0){		// 未設定のとき
+				$this->tmpl->addVar("show_member_info_option", "gender_none", 'selected');
+			} else if ($this->gender == 1){
+				$this->tmpl->addVar("show_member_info_option", "gender_male", 'selected');
+			} else {
+				$this->tmpl->addVar("show_member_info_option", "gender_female", 'selected');
+			}
+			$this->tmpl->addVar("show_member_info_option", "birthday", $this->convertToDispDate($birthday));			// 生年月日
+				
+			// フォトギャラリー追加分
+			$this->tmpl->addVar("show_member_info_option", "sports", $sports);		// 現在やっているスポーツ
 		}
-			
+		
 		if (!empty($this->memberType)){		// 仮会員のときは変更不可
 			$this->tmpl->addVar("_widget", "member_no_disabled", 'disabled');		// 会員No
-			$this->tmpl->addVar("_widget", "email_disabled", 'disabled');		// eメール(ログインアカウント)
+			$this->tmpl->addVar("_widget", "email_disabled", 'readonly');		// eメール(ログインアカウント)
 			$this->tmpl->addVar("_widget", "mobile_disabled", 'disabled');		// 携帯電話
 			$this->tmpl->addVar("_widget", "family_name_disabled", 'disabled');		// 会員名(姓)
 			$this->tmpl->addVar("_widget", "first_name_disabled", 'disabled');		// 会員名(名)
@@ -536,11 +563,13 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 			$this->tmpl->addVar("_widget", "address2_disabled", 'disabled');		// 住所2
 			$this->tmpl->addVar("_widget", "phone_disabled", 'disabled');		// 電話番号
 			$this->tmpl->addVar("_widget", "fax_disabled", 'disabled');		// FAX
-			$this->tmpl->addVar("_widget", "birthday_disabled", 'disabled');		// 生年月日
-			$this->tmpl->addVar("_widget", "calender_disabled", 'disabled');		// カレンダー
-			
 			$this->tmpl->addVar("_widget", "state_disabled", 'disabled');		// 都道府県
-			$this->tmpl->addVar("_widget", "gender_disabled", 'disabled');		// 性別
+			
+			if (photo_shopCommonDef::MEMBER_INFO_OPTION){
+				$this->tmpl->addVar("show_member_info_option", "birthday_disabled", 'disabled');		// 生年月日
+				$this->tmpl->addVar("show_member_info_option", "calender_disabled", 'disabled');		// カレンダー
+				$this->tmpl->addVar("show_member_info_option", "gender_disabled", 'disabled');		// 性別
+			}
 		}
 		
 		// ボタンの設定
@@ -561,7 +590,7 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 				$this->tmpl->addVar("_widget", "title", '仮会員詳細');
 			}
 			
-			$this->tmpl->addVar("_widget", "email_disabled", 'disabled');		// eメール(ログインアカウント)
+			$this->tmpl->addVar("_widget", "email_disabled", 'readonly');		// eメール(ログインアカウント)
 			
 			// パスワード送信ボタンの使用制御
 			//$this->tmpl->setAttribute('send_password', 'visibility', 'visible');
@@ -574,7 +603,7 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 			}
 		}
 		// メール送信可否状況によるボタンの制御
-		$useEmail = $this->mainDb->getConfig(self::USE_EMAIL);
+		$useEmail = self::$_mainDb->getConfig(self::USE_EMAIL);
 		if ($useEmail != '1'){		// メール送信不可のとき
 			$this->tmpl->addVar("_widget", "send_message", 'メール送信不可に設定されています<br>');
 			$this->tmpl->addVar("_widget", "send_pwd", 'disabled');
@@ -584,7 +613,9 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 		// 値を埋め込む
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);
 		$this->tmpl->addVar("_widget", "member_type", $this->memberType);
-		//$this->tmpl->addVar("_widget", "script_url", $gEnvManager->getScriptsUrl());	// スクリプトパスの設定
+
+		// 「戻る」ボタンの表示
+		if ($this->_openBy == 'simple' || $this->_openBy == 'tabs') $this->tmpl->setAttribute('cancel_button', 'visibility', 'hidden');		// 詳細画面のみの表示またはタブ表示のときは戻るボタンを隠す
 	}
 	/**
 	 * 取得したデータをテンプレートに設定する
@@ -596,13 +627,6 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 	 */
 	function memberListLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-		
-		// 行カラーの設定
-		$lineColor = '';
-		if ($index % 2 != 0){
-			$lineColor = 'class="even"';		// 偶数行
-		}
 		// 項目選択のラジオボタンの状態
 		if (empty($this->memberType)){
 			$serial = $this->convertToDispString($fetchedRow['sm_serial']);
@@ -658,8 +682,6 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 	 */
 	function stateLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		$selected = '';
 		if ($fetchedRow['gz_id'] == $this->state){		// 選択中の都道府県
 			$selected = 'selected';
@@ -696,7 +718,7 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 		} else {
 			$ret = $this->db->delMemberBySerial(1, $serial);
 		}
-		if ($ret) $this->sysDb->delLoginUser($loginUserId);
+		if ($ret) $this->_db->delLoginUser($loginUserId);
 
 		if ($ret){		// データ削除成功のとき
 			return true;
