@@ -8,15 +8,17 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_mainOrderDb.php 1577 2009-03-14 05:52:06Z fishbone $
+ * @version    SVN: $Id: ec_mainOrderDb.php 5434 2012-12-06 12:32:21Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
 
 class ec_mainOrderDb extends BaseDb
 {
+	const NO_ID = 'order_no';		// 注文番号取得用
+	
 	/**
 	 * 正会員情報を取得
 	 *
@@ -116,13 +118,15 @@ class ec_mainOrderDb extends BaseDb
 	 * @param float $deliv_fee				配送料
 	 * @param float $charge					手数料
 	 * @param float $total					支払い総額
+	 * @param string $discount_desc			値引き説明
 	 * @return								true=成功、false=失敗
 	 */
 	function updateOrderSheet($userId, $lang, $clientId,
 				$custm_id, $custm_name, $custm_name_kana, $custm_person, $custm_person_kana, $custm_zipcode, $custm_state_id, $custm_address, $custm_address2, $custm_phone, $custm_fax, $custm_email, $custm_country_id, 
 				$deliv_id, $deliv_name, $deliv_name_kana, $deliv_person, $deliv_person_kana, $deliv_zipcode, $deliv_state_id, $deliv_address, $deliv_address2, $deliv_phone, $deliv_fax, $deliv_email, $deliv_country_id,
 				$bill_id,  $bill_name,  $bill_name_kana,  $bill_person,  $bill_person_kana,  $bill_zipcode,  $bill_state_id,  $bill_address, $bill_address2, $bill_phone,  $bill_fax, $bill_email, $bill_country_id,
-				$deliv_method_id, $pay_method_id, $card_type, $card_owner, $card_number, $card_expires, $demand_dt, $demand_time, $appoint_dt, $currency_id, $subtotal, $discount, $deliv_fee, $charge, $total)
+				$deliv_method_id, $pay_method_id, $card_type, $card_owner, $card_number, $card_expires, $demand_dt, $demand_time, $appoint_dt, $currency_id, $subtotal, $discount, $deliv_fee, $charge, $total,
+				$discount_desc = '')
 	{
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$updateUserId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
@@ -172,7 +176,7 @@ class ec_mainOrderDb extends BaseDb
 				return false;
 			}
 		}
-		
+
 		// 登録済みかどうか確認
 		$queryStr = 'SELECT * FROM order_sheet WHERE oe_user_id = ? AND oe_language_id = ?';
 		$ret = $this->selectRecord($queryStr, array($keyUserId, $keyLang), $row);
@@ -228,7 +232,8 @@ class ec_mainOrderDb extends BaseDb
 			$queryStr .=     'oe_card_expires = ?, ';
 			$queryStr .=     'oe_demand_dt = ?, ';
 			$queryStr .=     'oe_demand_time = ?, ';
-			$queryStr .=     'oe_appoint_dt = ?, ';			
+			$queryStr .=     'oe_appoint_dt = ?, ';
+			$queryStr .=     'oe_discount_desc = ?, ';			// 値引き説明
 			$queryStr .=     'oe_currency_id = ?, ';			
 			$queryStr .=     'oe_subtotal = ?, ';			
 			$queryStr .=     'oe_discount = ?, ';			
@@ -236,6 +241,7 @@ class ec_mainOrderDb extends BaseDb
 			$queryStr .=     'oe_charge = ?, ';			
 			$queryStr .=     'oe_total = ?, ';
 			$queryStr .=     'oe_client_id = ?, ';			// クライアントID
+			$queryStr .=     'oe_session = ?, ';			// セッションID
 			$queryStr .=     'oe_update_user_id = ?, ';
 			$queryStr .=     'oe_update_dt = ? ';
 			$queryStr .=   'WHERE oe_serial = ? ';
@@ -243,8 +249,8 @@ class ec_mainOrderDb extends BaseDb
 				$custm_id, $custm_name, $custm_name_kana, $custm_person, $custm_person_kana, $custm_zipcode, $custm_state_id, $custm_address, $custm_address2, $custm_phone, $custm_fax, $custm_email, $custm_country_id, 
 				$deliv_id, $deliv_name, $deliv_name_kana, $deliv_person, $deliv_person_kana, $deliv_zipcode, $deliv_state_id, $deliv_address, $deliv_address2, $deliv_phone, $deliv_fax, $deliv_email, $deliv_country_id,
 				$bill_id,  $bill_name,  $bill_name_kana,  $bill_person,  $bill_person_kana,  $bill_zipcode,  $bill_state_id,  $bill_address, $bill_address2,  $bill_phone,  $bill_fax, $bill_email, $bill_country_id,
-				$deliv_method_id, $pay_method_id, $card_type, $card_owner, $card_number, $card_expires, $demand_dt, $demand_time, $appoint_dt, $currency_id, $subtotal, $discount, $deliv_fee, $charge, $total,
-				$clientId, $updateUserId, $now, $row['oe_serial']));
+				$deliv_method_id, $pay_method_id, $card_type, $card_owner, $card_number, $card_expires, $demand_dt, $demand_time, $appoint_dt, $discount_desc, $currency_id, $subtotal, $discount, $deliv_fee, $charge, $total,
+				$clientId, session_id(), $updateUserId, $now, $row['oe_serial']));
 		} else {
 			// 新規レコードを追加
 			$queryStr  = 'INSERT INTO order_sheet (';
@@ -297,7 +303,8 @@ class ec_mainOrderDb extends BaseDb
 			$queryStr .=     'oe_card_expires, ';
 			$queryStr .=     'oe_demand_dt, ';
 			$queryStr .=     'oe_demand_time, ';			
-			$queryStr .=     'oe_appoint_dt, ';			
+			$queryStr .=     'oe_appoint_dt, ';
+			$queryStr .=     'oe_discount_desc, ';			// 値引き説明
 			$queryStr .=     'oe_currency_id, ';			
 			$queryStr .=     'oe_subtotal, ';			
 			$queryStr .=     'oe_discount, ';			
@@ -305,6 +312,7 @@ class ec_mainOrderDb extends BaseDb
 			$queryStr .=     'oe_charge, ';			
 			$queryStr .=     'oe_total, ';
 			$queryStr .=     'oe_client_id, ';			// クライアントID
+			$queryStr .=     'oe_session, ';			// セッションID
 			$queryStr .=     'oe_update_user_id, ';
 			$queryStr .=     'oe_update_dt ';
 			$queryStr .= ') VALUES (';
@@ -366,13 +374,15 @@ class ec_mainOrderDb extends BaseDb
 			$queryStr .=   '?, ';
 			$queryStr .=   '?, ';
 			$queryStr .=   '?, ';
+			$queryStr .=   '?, ';
+			$queryStr .=   '?, ';
 			$queryStr .=   '?) ';
 			$ret = $this->execStatement($queryStr, array($keyUserId, $keyLang, 
 				$custm_id, $custm_name, $custm_name_kana, $custm_person, $custm_person_kana, $custm_zipcode, $custm_state_id, $custm_address, $custm_address2, $custm_phone, $custm_fax, $custm_email, $custm_country_id, 
 				$deliv_id, $deliv_name, $deliv_name_kana, $deliv_person, $deliv_person_kana, $deliv_zipcode, $deliv_state_id, $deliv_address, $deliv_address2, $deliv_phone, $deliv_fax, $deliv_email, $deliv_country_id,
 				$bill_id,  $bill_name,  $bill_name_kana,  $bill_person,  $bill_person_kana,  $bill_zipcode,  $bill_state_id,  $bill_address, $bill_address2, $bill_phone,  $bill_fax, $bill_email, $bill_country_id,
-				$deliv_method_id, $pay_method_id, $card_type, $card_owner, $card_number, $card_expires, $demand_dt, $demand_time, $appoint_dt, $currency_id, $subtotal, $discount, $deliv_fee, $charge, $total,
-				$clientId, $updateUserId, $now));
+				$deliv_method_id, $pay_method_id, $card_type, $card_owner, $card_number, $card_expires, $demand_dt, $demand_time, $appoint_dt, $discount_desc, $currency_id, $subtotal, $discount, $deliv_fee, $charge, $total,
+				$clientId, session_id(), $updateUserId, $now));
 		}
 		// トランザクション確定
 		$ret = $this->endTransaction();
@@ -449,6 +459,8 @@ class ec_mainOrderDb extends BaseDb
 	 * @param timestamp $now				更新日時
 	 * @param int       $newId				新規ID
 	 * @param int       $newSerial			新規シリアル番号
+	 * @param string $discount_desc			値引き説明
+	 * @param timestamp $pay_dt				支払い日時
 	 * @return								true=成功、false=失敗
 	 */
 	function updateOrder($serial, $userId, $lang, $order_no,
@@ -457,8 +469,10 @@ class ec_mainOrderDb extends BaseDb
 				$bill_id,  $bill_name,  $bill_name_kana,  $bill_person,  $bill_person_kana,  $bill_zipcode,  $bill_state_id,  $bill_address, $bill_address2,  $bill_phone,  $bill_fax, $bill_email, $bill_country_id,
 				$deliv_method_id, $pay_method_id, $card_type, $card_owner, $card_number, $card_expires, $demand_dt, $demand_time, $appoint_dt, $currency_id, $subtotal, $discount, $deliv_fee, $charge, $total,
 				$order_status, $estimate_dt, $regist_dt, $order_dt, $deliv_dt, $close_dt, 
-				$updateUserId, $now, &$newId, &$newSerial)
+				$updateUserId, $now, &$newId, &$newSerial, $discount_desc = '', $pay_dt = '')
 	{
+		if (empty($pay_dt)) $pay_dt = $this->gEnv->getInitValueOfTimestamp();		// 日時初期化値
+		
 		$historyIndex = 0;		// 履歴番号
 		if ($serial == 0){			// 新規登録のとき
 			// 新規IDを作成
@@ -544,7 +558,8 @@ class ec_mainOrderDb extends BaseDb
 		$queryStr .=     'or_card_expires, ';
 		$queryStr .=     'or_demand_dt, ';			
 		$queryStr .=     'or_demand_time, ';
-		$queryStr .=     'or_appoint_dt, ';			
+		$queryStr .=     'or_appoint_dt, ';
+		$queryStr .=     'or_discount_desc, ';			// 値引き説明
 		$queryStr .=     'or_currency_id, ';			
 		$queryStr .=     'or_subtotal, ';			
 		$queryStr .=     'or_discount, ';			
@@ -556,7 +571,8 @@ class ec_mainOrderDb extends BaseDb
 		$queryStr .=     'or_regist_dt, ';
 		$queryStr .=     'or_order_dt, ';
 		$queryStr .=     'or_deliv_dt, ';
-		$queryStr .=     'or_close_dt, ';					
+		$queryStr .=     'or_close_dt, ';
+		$queryStr .=     'or_pay_dt, ';				// 支払い日時
 		$queryStr .=     'or_create_user_id, ';
 		$queryStr .=     'or_create_dt ';
 		$queryStr .= ') VALUES (';
@@ -626,13 +642,15 @@ class ec_mainOrderDb extends BaseDb
 		$queryStr .=   '?, ';
 		$queryStr .=   '?, ';
 		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
 		$queryStr .=   '?) ';
 		$ret = $this->execStatement($queryStr, array($id, $historyIndex, $userId, $lang, $order_no,
 			$custm_id, $custm_name, $custm_name_kana, $custm_person, $custm_person_kana, $custm_zipcode, $custm_state_id, $custm_address, $custm_address2, $custm_phone, $custm_fax, $custm_email, $custm_country_id, 
 			$deliv_id, $deliv_name, $deliv_name_kana, $deliv_person, $deliv_person_kana, $deliv_zipcode, $deliv_state_id, $deliv_address, $deliv_address2, $deliv_phone, $deliv_fax, $deliv_email, $deliv_country_id,
 			$bill_id,  $bill_name,  $bill_name_kana,  $bill_person,  $bill_person_kana,  $bill_zipcode,  $bill_state_id,  $bill_address, $bill_address2,  $bill_phone,  $bill_fax, $bill_email, $bill_country_id,
-			$deliv_method_id, $pay_method_id, $card_type, $card_owner, $card_number, $card_expires, $demand_dt, $demand_time, $appoint_dt, $currency_id, $subtotal, $discount, $deliv_fee, $charge, $total,
-			$order_status, $estimate_dt, $regist_dt, $order_dt, $deliv_dt, $close_dt,
+			$deliv_method_id, $pay_method_id, $card_type, $card_owner, $card_number, $card_expires, $demand_dt, $demand_time, $appoint_dt, $discount_desc, $currency_id, $subtotal, $discount, $deliv_fee, $charge, $total,
+			$order_status, $estimate_dt, $regist_dt, $order_dt, $deliv_dt, $close_dt, $pay_dt,
 			$updateUserId, $now));
 			
 		// 新規のシリアル番号取得
@@ -646,8 +664,11 @@ class ec_mainOrderDb extends BaseDb
 	 *
 	 * @param int  $orderId				受注ID
 	 * @param int  $index				詳細インデックス(0～)
+	 * @param string    $productClass	商品クラス
 	 * @param int     $productId		商品ID
+	 * @param string    $productType	商品タイプ
 	 * @param string  $productName		商品名
+	 * @param string  $productCode		商品コード
 	 * @param float   $unitPrice		税抜き商品単価
 	 * @param int     $quantity			数量
 	 * @param float   $tax				税
@@ -656,14 +677,17 @@ class ec_mainOrderDb extends BaseDb
 	 * @param string  $now				現在日時
 	 * @return							true=成功、false=失敗
 	 */
-	function addOrderDetail($orderId, $index, $productId, $productName, $unitPrice, $quantity, $tax, $total, $userId, $now)
+	function addOrderDetail($orderId, $index, $productClass, $productId, $productType, $productName, $productCode, $unitPrice, $quantity, $tax, $total, $userId, $now)
 	{
 		// 新規レコードを追加
 		$queryStr  = 'INSERT INTO order_detail (';
 		$queryStr .=   'od_order_id, ';
 		$queryStr .=   'od_index, ';
+		$queryStr .=   'od_product_class, ';
 		$queryStr .=   'od_product_id, ';
+		$queryStr .=   'od_product_type_id, ';
 		$queryStr .=   'od_product_name, ';
+		$queryStr .=   'od_product_code, ';
 		$queryStr .=   'od_unit_price, ';
 		$queryStr .=   'od_quantity, ';
 		$queryStr .=   'od_tax, ';
@@ -680,23 +704,31 @@ class ec_mainOrderDb extends BaseDb
 		$queryStr .=   '?, ';
 		$queryStr .=   '?, ';
 		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
 		$queryStr .=   '?) ';
-		$ret = $this->execStatement($queryStr, array($orderId, $index, $productId, $productName, $unitPrice, $quantity, $tax, $total, $userId, $now));
+		$ret = $this->execStatement($queryStr, array($orderId, $index, $productClass, $productId, $productType, $productName, $productCode, $unitPrice, $quantity, $tax, $total, $userId, $now));
 		return $ret;
 	}
 	/**
 	 * 受注詳細一覧を取得
 	 *
 	 * @param string	$orderId			受注ID
+	 * @param string	$lang				言語ID
 	 * @param function	$callback			コールバック関数
 	 * @return 			なし
 	 */
-	function getOrderDetailList($orderId, $callback)
+	function getOrderDetailList($orderId, $lang, $callback)
 	{
-		$queryStr = 'SELECT * FROM order_detail ';
-		$queryStr .=  'WHERE od_order_id = ? AND od_deleted = false ';
-		$queryStr .=  'ORDER BY od_index ';
-		$this->selectLoop($queryStr, array($orderId), $callback, null);
+		$queryStr  = 'SELECT * FROM order_detail LEFT JOIN order_header ON od_order_id = or_id AND or_deleted = false ';
+		$queryStr .=   'LEFT JOIN currency ON or_currency_id = cu_id AND cu_language_id = ? ';
+		$queryStr .=   'LEFT JOIN product_type ON od_product_class = py_product_class AND od_product_type_id = py_id AND or_language_id = py_language_id AND py_deleted = false ';
+		$queryStr .=   'LEFT JOIN photo ON od_product_id = ht_id AND cu_language_id = ht_language_id AND ht_deleted = false ';		// フォトギャラリー画像用
+		$queryStr .=   'LEFT JOIN product ON od_product_id = pt_id AND cu_language_id = pt_language_id AND pt_deleted = false ';	// 一般商品用
+		$queryStr .=   'WHERE od_order_id = ? AND od_deleted = false ';
+		$queryStr .=   'ORDER BY od_index ';
+		$this->selectLoop($queryStr, array($lang, $orderId), $callback, null);
 	}
 	/**
 	 * 発注書を取得
@@ -746,9 +778,20 @@ class ec_mainOrderDb extends BaseDb
 	 */
 	function delOrderSheet($userId, $lang)
 	{
+		$startTran = false;			// この関数でトランザクションを開始したかどうか
+		
+		// トランザクション開始
+		if (!$this->isInTransaction()){
+			$this->startTransaction();
+			$startTran = true;
+		}
+		
 		$queryStr  = 'DELETE FROM order_sheet ';
 		$queryStr .=   'WHERE oe_user_id = ? AND oe_language_id = ?';
 		$ret = $this->execStatement($queryStr, array($userId, $lang));
+		
+		// トランザクション確定
+		if ($startTran) $ret = $this->endTransaction();
 		return $ret;
 	}
 	/**
@@ -759,9 +802,20 @@ class ec_mainOrderDb extends BaseDb
 	 */
 	function delOrderSheetByClientId($clientId)
 	{
+		$startTran = false;			// この関数でトランザクションを開始したかどうか
+		
+		// トランザクション開始
+		if (!$this->isInTransaction()){
+			$this->startTransaction();
+			$startTran = true;
+		}
+		
 		$queryStr  = 'DELETE FROM order_sheet ';
 		$queryStr .=   'WHERE oe_client_id = ?';
 		$ret = $this->execStatement($queryStr, array($clientId));
+		
+		// トランザクション確定
+		if ($startTran) $ret = $this->endTransaction();
 		return $ret;
 	}
 	/**
@@ -791,13 +845,28 @@ class ec_mainOrderDb extends BaseDb
 		$ret = $this->selectRecord($queryStr, array($serial), $row);
 		return $ret;
 	}
+	/**
+	 * 受注情報を注文番号で取得
+	 *
+	 * @param string $no			注文番号
+	 * @param array $row			取得レコード
+	 * @return						true=成功、false=失敗
+	 */
+	function getOrderByOrderNo($no, &$row)
+	{
+		$queryStr  = 'SELECT * FROM order_header LEFT JOIN _login_user ON or_create_user_id = lu_id AND lu_deleted = false ';
+		$queryStr .=   'WHERE or_deleted = false ';		// 未削除
+		$queryStr .=     'AND or_order_no = ? ';
+		$ret = $this->selectRecord($queryStr, array($no), $row);
+		return $ret;
+	}
 	/**
 	 * 最新の受注情報を取得
 	 *
 	 * @param array $row			取得レコード
 	 * @return						true=成功、false=失敗
 	 */
-	function getLatestOrder(&$row)
+/*	function getLatestOrder(&$row)
 	{
 		// 最大シリアル番号取得
 		$queryStr = 'SELECT max(or_serial) as ms FROM order_header ';
@@ -807,6 +876,39 @@ class ec_mainOrderDb extends BaseDb
 			$ret = $this->selectRecord($queryStr, array($maxRow['ms']), $row);
 		}
 		return $ret;
+	}*/
+	/**
+	 * 注文番号を取得
+	 *
+	 * @return string				注文番号。存在しない場合は空文字列。
+	 */
+	function getOrderNo()
+	{
+		$orderNo = '';
+		$queryStr = 'SELECT * FROM _used_no WHERE un_id = ?';
+		$ret = $this->selectRecord($queryStr, array(self::NO_ID), $row);
+		if ($ret) $orderNo = $row['un_value'];
+		return $orderNo;
+	}
+	/**
+	 * 注文番号を更新
+	 *
+	 * @param string $no	注文番号
+	 * @return				true=成功、false=失敗
+	 */
+	function updateOrderNo($no)
+	{
+		// データの確認
+		$queryStr = 'SELECT * FROM _used_no ';
+		$queryStr .=  'WHERE un_id  = ?';
+		$ret = $this->isRecordExists($queryStr, array(self::NO_ID));
+		if ($ret){
+			$queryStr = "UPDATE _used_no SET un_value = ? WHERE un_id = ?";
+			return $this->execStatement($queryStr, array($no, self::NO_ID));
+		} else {
+			$queryStr = "INSERT INTO _used_no (un_id, un_value) VALUES (?, ?)";
+			return $this->execStatement($queryStr, array(self::NO_ID, $no));
+		}
 	}
 	/**
 	 * 受注情報削除
@@ -868,6 +970,42 @@ class ec_mainOrderDb extends BaseDb
 		$queryStr .=  'ORDER BY gz_index ';
 		$this->selectLoop($queryStr, array($coutryId, $lang), $callback, null);
 	}
+	/**
+	 * IDから都道府県名を取得
+	 *
+	 * @param string	$coutryId			国ID
+	 * @param string	$lang				言語
+	 * @param string	$id					地域ID
+	 * @return string						名前
+	 */
+	function getStateName($coutryId, $lang, $id)
+	{
+		$queryStr = 'SELECT * FROM geo_zone ';
+		$queryStr .=  'WHERE gz_country_id = ? AND gz_type = 1 AND gz_language_id = ? AND gz_id = ?';
+		$ret = $this->selectRecord($queryStr, array($coutryId, $lang, $id), $row);
+		if ($ret){
+			return $row['gz_name'];
+		} else {
+			return '';
+		}
+	}
+	/**
+	 * 配送方法総数を取得
+	 *
+	 * @param string	$lang		言語
+	 * @param int		$setId		セットID
+	 * @return int					総数
+	 */
+	function getAllDelivMethodCount($lang, $setId = 0)
+	{
+//		$setId = 0;		// デフォルトの定義セット
+		$queryStr  = 'SELECT * FROM delivery_method_def ';
+		$queryStr .=   'WHERE do_deleted = false ';
+		$queryStr .=     'AND do_visible = true ';			// 表示状態
+		$queryStr .=     'AND do_language_id = ? ';
+		$queryStr .=     'AND do_set_id = ? ';
+		return $this->selectRecordCount($queryStr, array($lang, $setId));
+	}
 	/**
 	 * 配送方法を取得
 	 *
@@ -887,14 +1025,6 @@ class ec_mainOrderDb extends BaseDb
 		$queryStr .=  'ORDER BY do_index ';
 		$this->selectLoop($queryStr, array($lang, $setId), $callback, null);
 	}
-	 /*
-	function getAllDeliveryMethod($lang, $callback)
-	{
-		$queryStr = 'SELECT * FROM delivery_method ';
-		$queryStr .=  'WHERE dm_language_id = ? ';
-		$queryStr .=  'ORDER BY dm_sort_order ';
-		$this->selectLoop($queryStr, array($lang), $callback, null);
-	}*/
 	/**
 	 * 配送方法を取得
 	 *
@@ -914,6 +1044,22 @@ class ec_mainOrderDb extends BaseDb
 		$ret = $this->selectRecord($queryStr, array($id, $lang, $setId), $row);
 		return $ret;
 	}
+	/**
+	 * 支払い方法総数を取得
+	 *
+	 * @param string	$lang		言語
+	 * @return int					総数
+	 */
+	function getAllPaymentMethodCount($lang)
+	{
+		$setId = 0;		// デフォルトの定義セット
+		$queryStr  = 'SELECT * FROM pay_method_def ';
+		$queryStr .=   'WHERE po_deleted = false ';
+		$queryStr .=    'AND po_visible = true ';			// 表示状態
+		$queryStr .=    'AND po_language_id = ? ';
+		$queryStr .=    'AND po_set_id = ? ';
+		return $this->selectRecordCount($queryStr, array($lang, $setId));
+	}
 	/**
 	 * 支払い方法を取得
 	 *
@@ -951,6 +1097,27 @@ class ec_mainOrderDb extends BaseDb
 		$ret = $this->selectRecord($queryStr, array($id, $lang, $setId), $row);
 		return $ret;
 	}
+	/**
+	 * インナーウィジェットのメソッド定義を取得
+	 *
+	 * @param string    $type			メソッド種別
+	 * @param string	$lang			言語
+	 * @param array     $rows			取得レコード
+	 * @return bool						true=取得、false=取得せず
+	 */
+	function getAllIWidgetMethod($type, $lang, &$rows)
+	{
+		$setId = 0;		// デフォルトの定義セット
+		$queryStr  = 'SELECT * FROM _iwidget_method ';
+		$queryStr .=   'WHERE id_deleted = false ';
+		$queryStr .=     'AND id_visible = true ';			// 表示状態
+		$queryStr .=     'AND id_type = ? ';
+		$queryStr .=     'AND id_language_id = ? ';
+		$queryStr .=     'AND id_set_id = ? ';
+		$queryStr .=   'ORDER BY id_index ';
+		$retValue = $this->selectRecords($queryStr, array($type, $lang, $setId), $rows);
+		return $retValue;
+	}
 	/**
 	 * 会員情報を取得
 	 *
@@ -1047,11 +1214,14 @@ class ec_mainOrderDb extends BaseDb
 	 */
 	function getOrderHeaderByUser($userId, $callback)
 	{
-		$queryStr = 'SELECT * FROM order_header LEFT JOIN _login_user ON or_user_id = lu_id AND lu_deleted = false ';
-		$queryStr .=  'WHERE or_deleted = false ';// 削除されていない
-		$queryStr .=    'AND or_user_id = ? ';
-		$queryStr .=  'ORDER BY or_id desc';
-		$this->selectLoop($queryStr, array($userId), $callback, null);
+		$initDt = $this->gEnv->getInitValueOfTimestamp();		// 日時初期化値
+		
+		$queryStr  = 'SELECT * FROM order_header LEFT JOIN _login_user ON or_user_id = lu_id AND lu_deleted = false ';
+		$queryStr .=   'WHERE or_deleted = false ';// 削除されていない
+		$queryStr .=     'AND or_user_id = ? ';
+		$queryStr .=     'AND or_pay_dt != ? ';		// 支払い済み
+		$queryStr .=   'ORDER BY or_id desc';
+		$this->selectLoop($queryStr, array($userId, $initDt), $callback);
 	}
 	/**
 	 * 指定受注項目が指定ユーザの受注であるか判断
@@ -1112,5 +1282,68 @@ class ec_mainOrderDb extends BaseDb
 		$ret = $this->selectRecord($queryStr, array($id), $row);
 		return $ret;
 	}
+	/**
+	 * 商品記録を更新
+	 *
+	 * @param int	  $id			商品ID
+	 * @param string  $lang			言語ID
+	 * @param array	$updateParam	更新パラメータ
+	 * @return bool					true = 成功、false = 失敗
+	 */
+	function updateProductRecord($id, $lang, $updateParam)
+	{
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
+		
+		// パラメータエラーチェック
+		$keys = array_keys($updateParam);
+		if (in_array('pe_serial', $keys)) return false;
+				
+		// 既存データ取得
+		$queryStr = 'SELECT * FROM product_record ';
+		$queryStr .=  'WHERE pe_product_id = ? ';
+		$queryStr .=    'AND pe_language_id = ? ';
+		$ret = $this->selectRecord($queryStr, array($id, $lang), $stockRow);
+		if ($ret){	// データが存在するとき
+			// ##### データを更新 #####
+			// レコード更新
+			$queryStr = 'UPDATE product_record ';
+			$queryStr .=  'SET ';
+			$values = array();
+			for ($i = 0; $i < count($keys); $i++){
+				$queryStr .= $keys[$i] . ' = ?, ';
+				$values[] = $updateParam[$keys[$i]];
+			}
+			$queryStr .= 'pe_update_user_id = ?, '; $values[] = $userId;
+			$queryStr .= 'pe_update_dt = ? '; $values[] = $now;
+			$queryStr .=  'WHERE pe_serial = ? ';
+			$values[] = $stockRow['pe_serial'];
+			$ret =$this->execStatement($queryStr, $values);
+		} else {
+			// ##### データを新規追加 #####
+			// 新規レコード追加
+			$queryStr = 'INSERT INTO product_record ';
+			$queryStr .=  '(';
+		
+			$valueStr = '(';
+			$values = array();
+			for ($i = 0; $i < count($keys); $i++){
+				$queryStr .= $keys[$i] . ', ';
+				$valueStr .= '?, ';
+				$values[] = $updateParam[$keys[$i]];
+			}
+			$queryStr .= 'pe_product_id, pe_language_id, pe_update_user_id, pe_update_dt) ';
+			$valueStr .= '?, ?, ?, ?) ';
+			$values[] = $id;
+			$values[] = $lang;
+			$values[] = $userId;
+			$values[] = $now;
+			
+			$queryStr .=  'VALUES ';
+			$queryStr .=  $valueStr;
+			$ret =$this->execStatement($queryStr, $values);
+		}
+		return $ret;
+	}
 }
 ?>
