@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_menuOtherWidgetContainer.php 5383 2012-11-14 23:55:06Z fishbone $
+ * @version    SVN: $Id: admin_ec_menuOtherWidgetContainer.php 5427 2012-12-05 13:59:38Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_ec_menuBaseWidgetContainer.php');
@@ -56,11 +56,13 @@ class admin_ec_menuOtherWidgetContainer extends admin_ec_menuBaseWidgetContainer
 		if ($act == 'update'){		// 設定更新のとき
 			// 入力値を取得
 			$useVerticalMenu = ($request->trimValueOf('item_vertical_menu') == 'on') ? 1 : 0;		// 縦型メニューデザインを使用するかどうか
+			$linkProduct = ($request->trimValueOf('item_link_product') == 'on') ? 1 : 0;		// 商品詳細にカテゴリーを連動
 			$categoryCount	= $request->valueOf('item_category_count');		// 商品カテゴリー選択可能数
 			
 			if ($this->getMsgCount() == 0){			// エラーのないとき
 				$paramObj = new stdClass;
 				$paramObj->useVerticalMenu	= $useVerticalMenu;		// 縦型メニューデザインを使用するかどうか
+				$paramObj->linkProduct = $linkProduct;		// 商品詳細にカテゴリーを連動
 				$paramObj->categoryCount	= $categoryCount;		// 商品カテゴリー選択可能数
 				$ret = $this->updateWidgetParamObj($paramObj);
 				if ($ret){
@@ -73,10 +75,12 @@ class admin_ec_menuOtherWidgetContainer extends admin_ec_menuBaseWidgetContainer
 		} else {		// 初期表示の場合
 			// デフォルト値設定
 			$useVerticalMenu = 0;	// 縦型メニューデザインを使用するかどうか
+			$linkProduct = 1;		// 商品詳細にカテゴリーを連動
 			$categoryCount = self::DEFAULT_CATEGORY_COUNT;
 			$paramObj = $this->getWidgetParamObj();
 			if (!empty($paramObj)){
 				$useVerticalMenu	= $paramObj->useVerticalMenu;
+				$linkProduct		= $paramObj->linkProduct;		// 商品詳細にカテゴリーを連動
 				$categoryCount		= $paramObj->categoryCount;		// 商品カテゴリー選択可能数
 			}
 		}
@@ -85,6 +89,9 @@ class admin_ec_menuOtherWidgetContainer extends admin_ec_menuBaseWidgetContainer
 		$checked = '';
 		if ($useVerticalMenu) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "vertical_menu", $checked);		// 縦型メニューデザインを使用するかどうか
+		$checked = '';
+		if ($linkProduct) $checked = 'checked';
+		$this->tmpl->addVar("_widget", "link_product", $checked);		// 商品詳細にカテゴリーを連動
 		$this->tmpl->addVar("_widget", "category_count", $categoryCount);		// 商品カテゴリー選択可能数
 	}
 }
