@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_product_display2WidgetContainer.php 5380 2012-11-13 09:52:02Z fishbone $
+ * @version    SVN: $Id: ec_product_display2WidgetContainer.php 5399 2012-11-22 02:34:59Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -228,7 +228,7 @@ class ec_product_display2WidgetContainer extends BaseWidgetContainer
 		$imageTag = '<img class="product_image" src="' . $this->getUrl($imgUrl) . '" ';
 		$imageTag .= 'width="' . $this->imageWidth . '"';
 		$imageTag .= ' height="' . $this->imageHeight . '"';
-		$imageTag .= ' style="border:0" />';
+		$imageTag .= ' />';
 		
 		// 出力制御
 		if ($this->imgVisible){				// 画像の出力
