@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: backup.inc.php 1141 2008-10-27 06:10:58Z fishbone $
+ * @version    SVN: $Id: backup.inc.php 3474 2010-08-13 10:36:48Z fishbone $
  * @link       http://www.magic3.org
  */
 // Copyright (C)
@@ -115,27 +115,27 @@ function plugin_backup_action()
 	$body .= '</ul>'  . "\n";
 
 	if ($action == 'diff') {
-		$title = & $_title_backupdiff;
+		$title = $_title_backupdiff;
 		/*$old = ($s_age > 1) ? join('', $backups[$s_age - 1]['data']) : '';
 		$cur = join('', $backups[$s_age]['data']);*/
 		$old = ($s_age > 1) ? WikiPage::getPageBackup($page, $s_age - 1, true) : '';
 		$cur = WikiPage::getPageBackup($page, $s_age, true);
 		$body .= plugin_backup_diff(do_diff($old, $cur));
 	} else if ($s_action == 'nowdiff') {
-		$title = & $_title_backupnowdiff;
+		$title = $_title_backupnowdiff;
 		//$old = join('', $backups[$s_age]['data']);
 		$old = WikiPage::getPageBackup($page, $s_age, true);
 		$cur = join('', get_source($page));
 		$body .= plugin_backup_diff(do_diff($old, $cur));
 	} else if ($s_action == 'source') {
-		$title = & $_title_backupsource;
+		$title = $_title_backupsource;
 		//$body .= '<pre>' . htmlspecialchars(join('', $backups[$s_age]['data'])) . '</pre>' . "\n";
 		$body .= '<pre class="wiki_pre">' . htmlspecialchars(WikiPage::getPageBackup($page, $s_age, true)) . '</pre>' . "\n";
 	} else {
 		if (PLUGIN_BACKUP_DISABLE_BACKUP_RENDERING) {
 			die_message('This feature is prohibited');
 		} else {
-			$title = & $_title_backup;
+			$title = $_title_backup;
 			//$body .= $hr . "\n" . drop_submit(convert_html($backups[$s_age]['data']));
 			$body .= $hr . "\n" . drop_submit(convert_html(WikiPage::getPageBackup($page, $s_age)));
 		}
@@ -178,32 +178,18 @@ function plugin_backup_delete($page)
 		}
 	}
 
-/*	$script = get_script_uri();
-	$s_page = htmlspecialchars($page);
-	$body .= <<<EOD
-<p>$_msg_backup_adminpass</p>
-<form action="$script" method="post">
- <div>
-  <input type="hidden"   name="cmd"    value="backup" />
-  <input type="hidden"   name="page"   value="$s_page" />
-  <input type="hidden"   name="action" value="delete" />
-  <input type="password" name="pass"   size="12" />
-  <input type="submit"   name="ok"     value="$_btn_delete" />
- </div>
-</form>
-EOD;*/
 	$postScript = get_script_uri() . WikiParam::convQuery("?");
 	$s_page = htmlspecialchars($page);
 	$body .= <<<EOD
 <p>$_msg_backup_adminpass</p>
-<form action="$postScript" method="post">
+<form action="$postScript" method="post" class="form">
  <div>
   <input type="hidden"   name="wcmd"    value="backup" />
   <input type="hidden"   name="page"   value="$s_page" />
   <input type="hidden"   name="action" value="delete" />
   <input type="hidden"   name="pass" />
   <input type="password" name="password" size="12" />
-  <input type="submit"   name="ok"     value="$_btn_delete" onclick="this.form.pass.value = hex_md5(this.form.password.value);" />
+  <input type="submit"   name="ok"     class="button" value="$_btn_delete" onclick="this.form.pass.value = hex_md5(this.form.password.value);" />
  </div>
 </form>
 EOD;
